#[non_exhaustive]pub enum CreateSessionError {
NoSuchBucket(NoSuchBucket),
Unhandled(Unhandled),
}Expand description
Error type for the CreateSessionError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
NoSuchBucket(NoSuchBucket)
The specified bucket does not exist.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl CreateSessionError
impl CreateSessionError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the CreateSessionError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the CreateSessionError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_no_such_bucket(&self) -> bool
pub fn is_no_such_bucket(&self) -> bool
Returns true if the error kind is CreateSessionError::NoSuchBucket.