DeleteObjectAnnotationFluentBuilder

Struct DeleteObjectAnnotationFluentBuilder 

pub struct DeleteObjectAnnotationFluentBuilder { /* private fields */ }
Fluent builder constructing a request to DeleteObjectAnnotation.

Deletes a specific annotation from an Amazon S3 object. Use the x-amz-object-if-match header to perform a conditional delete that only succeeds if the object's ETag matches the provided value, preventing race conditions during concurrent updates.

Deleting an annotation is permanent. Annotations are not independently versioned, so there is no delete marker or way to recover a deleted annotation.

To use this operation, you must have the s3:DeleteObjectAnnotation permission. If the object is protected by Object Lock in governance mode, you must also include the x-amz-bypass-governance-retention header.

Annotations are not supported by the following features: S3 Inventory Reports, API Gateway, S3 Storage Lens, Amazon S3 File Gateway, Amazon FSx, S3 on Outposts, and S3 Express One Zone (directory buckets).

The following operations are related to DeleteObjectAnnotation:

Implementations

Source

impl DeleteObjectAnnotationFluentBuilder

pub fn as_input(&self) -> &DeleteObjectAnnotationInputBuilder

Access the DeleteObjectAnnotation as a reference.

pub async fn send( self, ) -> Result<DeleteObjectAnnotationOutput, SdkError<DeleteObjectAnnotationError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<DeleteObjectAnnotationOutput, DeleteObjectAnnotationError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn bucket(self, input: impl Into<String>) -> Self

The name of the bucket that contains the object.

pub fn set_bucket(self, input: Option<String>) -> Self

The name of the bucket that contains the object.

pub fn get_bucket(&self) -> &Option<String>

The name of the bucket that contains the object.

pub fn key(self, input: impl Into<String>) -> Self

The object key.

pub fn set_key(self, input: Option<String>) -> Self

The object key.

pub fn get_key(&self) -> &Option<String>

The object key.

pub fn annotation_name(self, input: impl Into<String>) -> Self

The name of the annotation to delete. Annotation names are UTF-8 encoded and cannot start with aws or s3 (case-insensitive).

Length Constraints: Minimum length of 1. Maximum length of 512 bytes.

pub fn set_annotation_name(self, input: Option<String>) -> Self

The name of the annotation to delete. Annotation names are UTF-8 encoded and cannot start with aws or s3 (case-insensitive).

Length Constraints: Minimum length of 1. Maximum length of 512 bytes.

pub fn get_annotation_name(&self) -> &Option<String>

The name of the annotation to delete. Annotation names are UTF-8 encoded and cannot start with aws or s3 (case-insensitive).

Length Constraints: Minimum length of 1. Maximum length of 512 bytes.

pub fn version_id(self, input: impl Into<String>) -> Self

The version ID of the object.

pub fn set_version_id(self, input: Option<String>) -> Self

The version ID of the object.

pub fn get_version_id(&self) -> &Option<String>

The version ID of the object.

pub fn request_payer(self, input: RequestPayer) -> Self

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

pub fn set_request_payer(self, input: Option<RequestPayer>) -> Self

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

pub fn get_request_payer(&self) -> &Option<RequestPayer>

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self

The account ID of the expected bucket owner.

pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self

The account ID of the expected bucket owner.

pub fn get_expected_bucket_owner(&self) -> &Option<String>

The account ID of the expected bucket owner.

pub fn object_if_match(self, input: impl Into<String>) -> Self

If specified, the operation only succeeds if the object's ETag matches the provided value.

pub fn set_object_if_match(self, input: Option<String>) -> Self

If specified, the operation only succeeds if the object's ETag matches the provided value.

pub fn get_object_if_match(&self) -> &Option<String>

If specified, the operation only succeeds if the object's ETag matches the provided value.