#[non_exhaustive]pub struct DeleteObjectAnnotationInputBuilder { /* private fields */ }Expand description
A builder for DeleteObjectAnnotationInput.
Implementations
Sourceimpl DeleteObjectAnnotationInputBuilder
impl DeleteObjectAnnotationInputBuilder
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket that contains the object.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket that contains the object.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket that contains the object.
Sourcepub fn annotation_name(self, input: impl Into<String>) -> Self
pub fn annotation_name(self, input: impl Into<String>) -> Self
The name of the annotation to delete. Annotation names are UTF-8 encoded and cannot start with aws or s3 (case-insensitive).
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
This field is required.Sourcepub fn set_annotation_name(self, input: Option<String>) -> Self
pub fn set_annotation_name(self, input: Option<String>) -> Self
The name of the annotation to delete. Annotation names are UTF-8 encoded and cannot start with aws or s3 (case-insensitive).
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
Sourcepub fn get_annotation_name(&self) -> &Option<String>
pub fn get_annotation_name(&self) -> &Option<String>
The name of the annotation to delete. Annotation names are UTF-8 encoded and cannot start with aws or s3 (case-insensitive).
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
Sourcepub fn version_id(self, input: impl Into<String>) -> Self
pub fn version_id(self, input: impl Into<String>) -> Self
The version ID of the object.
Sourcepub fn set_version_id(self, input: Option<String>) -> Self
pub fn set_version_id(self, input: Option<String>) -> Self
The version ID of the object.
Sourcepub fn get_version_id(&self) -> &Option<String>
pub fn get_version_id(&self) -> &Option<String>
The version ID of the object.
Sourcepub fn request_payer(self, input: RequestPayer) -> Self
pub fn request_payer(self, input: RequestPayer) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
pub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_payer(&self) -> &Option<RequestPayer>
pub fn get_request_payer(&self) -> &Option<RequestPayer>
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner.
Sourcepub fn object_if_match(self, input: impl Into<String>) -> Self
pub fn object_if_match(self, input: impl Into<String>) -> Self
If specified, the operation only succeeds if the object's ETag matches the provided value.
Sourcepub fn set_object_if_match(self, input: Option<String>) -> Self
pub fn set_object_if_match(self, input: Option<String>) -> Self
If specified, the operation only succeeds if the object's ETag matches the provided value.
Sourcepub fn get_object_if_match(&self) -> &Option<String>
pub fn get_object_if_match(&self) -> &Option<String>
If specified, the operation only succeeds if the object's ETag matches the provided value.
Sourcepub fn build(self) -> Result<DeleteObjectAnnotationInput, BuildError>
pub fn build(self) -> Result<DeleteObjectAnnotationInput, BuildError>
Consumes the builder and constructs a DeleteObjectAnnotationInput.
Sourceimpl DeleteObjectAnnotationInputBuilder
impl DeleteObjectAnnotationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DeleteObjectAnnotationOutput, SdkError<DeleteObjectAnnotationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DeleteObjectAnnotationOutput, SdkError<DeleteObjectAnnotationError, HttpResponse>>
Sends a request with this input using the given client.