#[non_exhaustive]pub struct DeleteObjectAnnotationOutputBuilder { /* private fields */ }Expand description
A builder for DeleteObjectAnnotationOutput.
Implementations
Sourceimpl DeleteObjectAnnotationOutputBuilder
impl DeleteObjectAnnotationOutputBuilder
Sourcepub fn object_version_id(self, input: impl Into<String>) -> Self
pub fn object_version_id(self, input: impl Into<String>) -> Self
The version ID of the object that the annotation was deleted from.
Sourcepub fn set_object_version_id(self, input: Option<String>) -> Self
pub fn set_object_version_id(self, input: Option<String>) -> Self
The version ID of the object that the annotation was deleted from.
Sourcepub fn get_object_version_id(&self) -> &Option<String>
pub fn get_object_version_id(&self) -> &Option<String>
The version ID of the object that the annotation was deleted from.
Sourcepub fn request_charged(self, input: RequestCharged) -> Self
pub fn request_charged(self, input: RequestCharged) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
pub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_charged(&self) -> &Option<RequestCharged>
pub fn get_request_charged(&self) -> &Option<RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn build(self) -> DeleteObjectAnnotationOutput
pub fn build(self) -> DeleteObjectAnnotationOutput
Consumes the builder and constructs a DeleteObjectAnnotationOutput.