ListObjectAnnotationsInputBuilder

Struct ListObjectAnnotationsInputBuilder 

#[non_exhaustive]
pub struct ListObjectAnnotationsInputBuilder { /* private fields */ }
Implementations

Source

impl ListObjectAnnotationsInputBuilder

pub fn bucket(self, input: impl Into<String>) -> Self

The name of the bucket that contains the object.

This field is required.
pub fn set_bucket(self, input: Option<String>) -> Self

The name of the bucket that contains the object.

pub fn get_bucket(&self) -> &Option<String>

The name of the bucket that contains the object.

pub fn key(self, input: impl Into<String>) -> Self

The object key.

This field is required.
pub fn set_key(self, input: Option<String>) -> Self

The object key.

pub fn get_key(&self) -> &Option<String>

The object key.

pub fn version_id(self, input: impl Into<String>) -> Self

The version ID of the object.

pub fn set_version_id(self, input: Option<String>) -> Self

The version ID of the object.

pub fn get_version_id(&self) -> &Option<String>

The version ID of the object.

pub fn max_annotation_results(self, input: i32) -> Self

The maximum number of annotations to return in the response. Maximum is 1,000.

pub fn set_max_annotation_results(self, input: Option<i32>) -> Self

The maximum number of annotations to return in the response. Maximum is 1,000.

pub fn get_max_annotation_results(&self) -> &Option<i32>

The maximum number of annotations to return in the response. Maximum is 1,000.

pub fn annotation_prefix(self, input: impl Into<String>) -> Self

Filter results to annotations whose name begins with the specified prefix.

pub fn set_annotation_prefix(self, input: Option<String>) -> Self

Filter results to annotations whose name begins with the specified prefix.

pub fn get_annotation_prefix(&self) -> &Option<String>

Filter results to annotations whose name begins with the specified prefix.

pub fn continuation_token(self, input: impl Into<String>) -> Self

Continuation token returned by a previous request to retrieve the next page.

pub fn set_continuation_token(self, input: Option<String>) -> Self

Continuation token returned by a previous request to retrieve the next page.

pub fn get_continuation_token(&self) -> &Option<String>

Continuation token returned by a previous request to retrieve the next page.

pub fn request_payer(self, input: RequestPayer) -> Self

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

pub fn set_request_payer(self, input: Option<RequestPayer>) -> Self

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

pub fn get_request_payer(&self) -> &Option<RequestPayer>

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self

The account ID of the expected bucket owner.

pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self

The account ID of the expected bucket owner.

pub fn get_expected_bucket_owner(&self) -> &Option<String>

The account ID of the expected bucket owner.

pub fn build(self) -> Result<ListObjectAnnotationsInput, BuildError>

Consumes the builder and constructs a ListObjectAnnotationsInput.

Source

impl ListObjectAnnotationsInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<ListObjectAnnotationsOutput, SdkError<ListObjectAnnotationsError, HttpResponse>>

Sends a request with this input using the given client.