#[non_exhaustive]pub struct ListObjectAnnotationsOutputBuilder { /* private fields */ }Expand description
A builder for ListObjectAnnotationsOutput.
Implementations
Sourceimpl ListObjectAnnotationsOutputBuilder
impl ListObjectAnnotationsOutputBuilder
Sourcepub fn annotations(self, input: AnnotationEntry) -> Self
pub fn annotations(self, input: AnnotationEntry) -> Self
Appends an item to annotations.
To override the contents of this collection use set_annotations.
The list of annotations attached to the object.
Sourcepub fn set_annotations(self, input: Option<Vec<AnnotationEntry>>) -> Self
pub fn set_annotations(self, input: Option<Vec<AnnotationEntry>>) -> Self
The list of annotations attached to the object.
Sourcepub fn get_annotations(&self) -> &Option<Vec<AnnotationEntry>>
pub fn get_annotations(&self) -> &Option<Vec<AnnotationEntry>>
The list of annotations attached to the object.
Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The bucket name.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The bucket name.
Sourcepub fn object_version_id(self, input: impl Into<String>) -> Self
pub fn object_version_id(self, input: impl Into<String>) -> Self
The version ID of the object.
Sourcepub fn set_object_version_id(self, input: Option<String>) -> Self
pub fn set_object_version_id(self, input: Option<String>) -> Self
The version ID of the object.
Sourcepub fn get_object_version_id(&self) -> &Option<String>
pub fn get_object_version_id(&self) -> &Option<String>
The version ID of the object.
Sourcepub fn annotation_prefix(self, input: impl Into<String>) -> Self
pub fn annotation_prefix(self, input: impl Into<String>) -> Self
The prefix used to filter the response.
Sourcepub fn set_annotation_prefix(self, input: Option<String>) -> Self
pub fn set_annotation_prefix(self, input: Option<String>) -> Self
The prefix used to filter the response.
Sourcepub fn get_annotation_prefix(&self) -> &Option<String>
pub fn get_annotation_prefix(&self) -> &Option<String>
The prefix used to filter the response.
Sourcepub fn max_annotation_results(self, input: i32) -> Self
pub fn max_annotation_results(self, input: i32) -> Self
The maximum number of annotations returned in the response.
Sourcepub fn set_max_annotation_results(self, input: Option<i32>) -> Self
pub fn set_max_annotation_results(self, input: Option<i32>) -> Self
The maximum number of annotations returned in the response.
Sourcepub fn get_max_annotation_results(&self) -> &Option<i32>
pub fn get_max_annotation_results(&self) -> &Option<i32>
The maximum number of annotations returned in the response.
Sourcepub fn annotation_count(self, input: i32) -> Self
pub fn annotation_count(self, input: i32) -> Self
The number of annotations returned.
Sourcepub fn set_annotation_count(self, input: Option<i32>) -> Self
pub fn set_annotation_count(self, input: Option<i32>) -> Self
The number of annotations returned.
Sourcepub fn get_annotation_count(&self) -> &Option<i32>
pub fn get_annotation_count(&self) -> &Option<i32>
The number of annotations returned.
Sourcepub fn continuation_token(self, input: impl Into<String>) -> Self
pub fn continuation_token(self, input: impl Into<String>) -> Self
The continuation token used in this request.
Sourcepub fn set_continuation_token(self, input: Option<String>) -> Self
pub fn set_continuation_token(self, input: Option<String>) -> Self
The continuation token used in this request.
Sourcepub fn get_continuation_token(&self) -> &Option<String>
pub fn get_continuation_token(&self) -> &Option<String>
The continuation token used in this request.
Sourcepub fn next_continuation_token(self, input: impl Into<String>) -> Self
pub fn next_continuation_token(self, input: impl Into<String>) -> Self
The continuation token to use to retrieve the next page of results.
Sourcepub fn set_next_continuation_token(self, input: Option<String>) -> Self
pub fn set_next_continuation_token(self, input: Option<String>) -> Self
The continuation token to use to retrieve the next page of results.
Sourcepub fn get_next_continuation_token(&self) -> &Option<String>
pub fn get_next_continuation_token(&self) -> &Option<String>
The continuation token to use to retrieve the next page of results.
Sourcepub fn request_charged(self, input: RequestCharged) -> Self
pub fn request_charged(self, input: RequestCharged) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
pub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_charged(&self) -> &Option<RequestCharged>
pub fn get_request_charged(&self) -> &Option<RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn build(self) -> ListObjectAnnotationsOutput
pub fn build(self) -> ListObjectAnnotationsOutput
Consumes the builder and constructs a ListObjectAnnotationsOutput.