ListObjectAnnotationsInput

Struct ListObjectAnnotationsInput 

#[non_exhaustive]
pub struct ListObjectAnnotationsInput { pub bucket: Option<String>, pub key: Option<String>, pub version_id: Option<String>, pub max_annotation_results: Option<i32>, pub annotation_prefix: Option<String>, pub continuation_token: Option<String>, pub request_payer: Option<RequestPayer>, pub expected_bucket_owner: Option<String>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
bucket: Option<String>

The name of the bucket that contains the object.

key: Option<String>

The object key.

version_id: Option<String>

The version ID of the object.

max_annotation_results: Option<i32>

The maximum number of annotations to return in the response. Maximum is 1,000.

annotation_prefix: Option<String>

Filter results to annotations whose name begins with the specified prefix.

continuation_token: Option<String>

Continuation token returned by a previous request to retrieve the next page.

request_payer: Option<RequestPayer>

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

expected_bucket_owner: Option<String>

The account ID of the expected bucket owner.

Implementations

Source

impl ListObjectAnnotationsInput

pub fn bucket(&self) -> Option<&str>

The name of the bucket that contains the object.

pub fn key(&self) -> Option<&str>

The object key.

pub fn version_id(&self) -> Option<&str>

The version ID of the object.

pub fn max_annotation_results(&self) -> Option<i32>

The maximum number of annotations to return in the response. Maximum is 1,000.

pub fn annotation_prefix(&self) -> Option<&str>

Filter results to annotations whose name begins with the specified prefix.

pub fn continuation_token(&self) -> Option<&str>

Continuation token returned by a previous request to retrieve the next page.

pub fn request_payer(&self) -> Option<&RequestPayer>

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

pub fn expected_bucket_owner(&self) -> Option<&str>

The account ID of the expected bucket owner.

Source

impl ListObjectAnnotationsInput

pub fn builder() -> ListObjectAnnotationsInputBuilder

Creates a new builder-style object to manufacture ListObjectAnnotationsInput.