#[non_exhaustive]pub struct PutBucketInventoryConfigurationInput {
pub bucket: Option<String>,
pub id: Option<String>,
pub inventory_configuration: Option<InventoryConfiguration>,
pub expected_bucket_owner: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the bucket where the inventory configuration will be stored.
Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format https://s3express-control.region-code.amazonaws.com/bucket-name . Virtual-hosted-style requests aren't supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide
id: Option<String>The ID used to identify the inventory configuration.
inventory_configuration: Option<InventoryConfiguration>Specifies the inventory configuration.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code 501 Not Implemented.
Implementations
Sourceimpl PutBucketInventoryConfigurationInput
impl PutBucketInventoryConfigurationInput
Sourcepub fn bucket(&self) -> Option<&str>
pub fn bucket(&self) -> Option<&str>
The name of the bucket where the inventory configuration will be stored.
Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format https://s3express-control.region-code.amazonaws.com/bucket-name . Virtual-hosted-style requests aren't supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide
Sourcepub fn inventory_configuration(&self) -> Option<&InventoryConfiguration>
pub fn inventory_configuration(&self) -> Option<&InventoryConfiguration>
Specifies the inventory configuration.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code 501 Not Implemented.
Sourceimpl PutBucketInventoryConfigurationInput
impl PutBucketInventoryConfigurationInput
Sourcepub fn builder() -> PutBucketInventoryConfigurationInputBuilder
pub fn builder() -> PutBucketInventoryConfigurationInputBuilder
Creates a new builder-style object to manufacture PutBucketInventoryConfigurationInput.