#[non_exhaustive]pub struct PutObjectAnnotationOutputBuilder { /* private fields */ }Expand description
A builder for PutObjectAnnotationOutput.
Implementations
Sourceimpl PutObjectAnnotationOutputBuilder
impl PutObjectAnnotationOutputBuilder
Sourcepub fn annotation_name(self, input: impl Into<String>) -> Self
pub fn annotation_name(self, input: impl Into<String>) -> Self
The name of the annotation.
Sourcepub fn set_annotation_name(self, input: Option<String>) -> Self
pub fn set_annotation_name(self, input: Option<String>) -> Self
The name of the annotation.
Sourcepub fn get_annotation_name(&self) -> &Option<String>
pub fn get_annotation_name(&self) -> &Option<String>
The name of the annotation.
Sourcepub fn object_version_id(self, input: impl Into<String>) -> Self
pub fn object_version_id(self, input: impl Into<String>) -> Self
The version ID of the object that the annotation was attached to.
Sourcepub fn set_object_version_id(self, input: Option<String>) -> Self
pub fn set_object_version_id(self, input: Option<String>) -> Self
The version ID of the object that the annotation was attached to.
Sourcepub fn get_object_version_id(&self) -> &Option<String>
pub fn get_object_version_id(&self) -> &Option<String>
The version ID of the object that the annotation was attached to.
Sourcepub fn checksum_crc32(self, input: impl Into<String>) -> Self
pub fn checksum_crc32(self, input: impl Into<String>) -> Self
The CRC32 checksum of the stored annotation.
Sourcepub fn set_checksum_crc32(self, input: Option<String>) -> Self
pub fn set_checksum_crc32(self, input: Option<String>) -> Self
The CRC32 checksum of the stored annotation.
Sourcepub fn get_checksum_crc32(&self) -> &Option<String>
pub fn get_checksum_crc32(&self) -> &Option<String>
The CRC32 checksum of the stored annotation.
Sourcepub fn checksum_crc32_c(self, input: impl Into<String>) -> Self
pub fn checksum_crc32_c(self, input: impl Into<String>) -> Self
The CRC32C checksum of the stored annotation.
Sourcepub fn set_checksum_crc32_c(self, input: Option<String>) -> Self
pub fn set_checksum_crc32_c(self, input: Option<String>) -> Self
The CRC32C checksum of the stored annotation.
Sourcepub fn get_checksum_crc32_c(&self) -> &Option<String>
pub fn get_checksum_crc32_c(&self) -> &Option<String>
The CRC32C checksum of the stored annotation.
Sourcepub fn checksum_crc64_nvme(self, input: impl Into<String>) -> Self
pub fn checksum_crc64_nvme(self, input: impl Into<String>) -> Self
The CRC64NVME checksum of the stored annotation.
Sourcepub fn set_checksum_crc64_nvme(self, input: Option<String>) -> Self
pub fn set_checksum_crc64_nvme(self, input: Option<String>) -> Self
The CRC64NVME checksum of the stored annotation.
Sourcepub fn get_checksum_crc64_nvme(&self) -> &Option<String>
pub fn get_checksum_crc64_nvme(&self) -> &Option<String>
The CRC64NVME checksum of the stored annotation.
Sourcepub fn checksum_sha1(self, input: impl Into<String>) -> Self
pub fn checksum_sha1(self, input: impl Into<String>) -> Self
The SHA1 checksum of the stored annotation.
Sourcepub fn set_checksum_sha1(self, input: Option<String>) -> Self
pub fn set_checksum_sha1(self, input: Option<String>) -> Self
The SHA1 checksum of the stored annotation.
Sourcepub fn get_checksum_sha1(&self) -> &Option<String>
pub fn get_checksum_sha1(&self) -> &Option<String>
The SHA1 checksum of the stored annotation.
Sourcepub fn checksum_sha256(self, input: impl Into<String>) -> Self
pub fn checksum_sha256(self, input: impl Into<String>) -> Self
The SHA256 checksum of the stored annotation.
Sourcepub fn set_checksum_sha256(self, input: Option<String>) -> Self
pub fn set_checksum_sha256(self, input: Option<String>) -> Self
The SHA256 checksum of the stored annotation.
Sourcepub fn get_checksum_sha256(&self) -> &Option<String>
pub fn get_checksum_sha256(&self) -> &Option<String>
The SHA256 checksum of the stored annotation.
Sourcepub fn checksum_sha512(self, input: impl Into<String>) -> Self
pub fn checksum_sha512(self, input: impl Into<String>) -> Self
The SHA512 checksum of the stored annotation.
Sourcepub fn set_checksum_sha512(self, input: Option<String>) -> Self
pub fn set_checksum_sha512(self, input: Option<String>) -> Self
The SHA512 checksum of the stored annotation.
Sourcepub fn get_checksum_sha512(&self) -> &Option<String>
pub fn get_checksum_sha512(&self) -> &Option<String>
The SHA512 checksum of the stored annotation.
Sourcepub fn checksum_md5(self, input: impl Into<String>) -> Self
pub fn checksum_md5(self, input: impl Into<String>) -> Self
The MD5 checksum of the stored annotation.
Sourcepub fn set_checksum_md5(self, input: Option<String>) -> Self
pub fn set_checksum_md5(self, input: Option<String>) -> Self
The MD5 checksum of the stored annotation.
Sourcepub fn get_checksum_md5(&self) -> &Option<String>
pub fn get_checksum_md5(&self) -> &Option<String>
The MD5 checksum of the stored annotation.
Sourcepub fn checksum_xxhash64(self, input: impl Into<String>) -> Self
pub fn checksum_xxhash64(self, input: impl Into<String>) -> Self
The XXHASH64 checksum of the stored annotation.
Sourcepub fn set_checksum_xxhash64(self, input: Option<String>) -> Self
pub fn set_checksum_xxhash64(self, input: Option<String>) -> Self
The XXHASH64 checksum of the stored annotation.
Sourcepub fn get_checksum_xxhash64(&self) -> &Option<String>
pub fn get_checksum_xxhash64(&self) -> &Option<String>
The XXHASH64 checksum of the stored annotation.
Sourcepub fn checksum_xxhash3(self, input: impl Into<String>) -> Self
pub fn checksum_xxhash3(self, input: impl Into<String>) -> Self
The XXHASH3 checksum of the stored annotation.
Sourcepub fn set_checksum_xxhash3(self, input: Option<String>) -> Self
pub fn set_checksum_xxhash3(self, input: Option<String>) -> Self
The XXHASH3 checksum of the stored annotation.
Sourcepub fn get_checksum_xxhash3(&self) -> &Option<String>
pub fn get_checksum_xxhash3(&self) -> &Option<String>
The XXHASH3 checksum of the stored annotation.
Sourcepub fn checksum_xxhash128(self, input: impl Into<String>) -> Self
pub fn checksum_xxhash128(self, input: impl Into<String>) -> Self
The XXHASH128 checksum of the stored annotation.
Sourcepub fn set_checksum_xxhash128(self, input: Option<String>) -> Self
pub fn set_checksum_xxhash128(self, input: Option<String>) -> Self
The XXHASH128 checksum of the stored annotation.
Sourcepub fn get_checksum_xxhash128(&self) -> &Option<String>
pub fn get_checksum_xxhash128(&self) -> &Option<String>
The XXHASH128 checksum of the stored annotation.
Sourcepub fn checksum_type(self, input: ChecksumType) -> Self
pub fn checksum_type(self, input: ChecksumType) -> Self
The type of checksum used.
Sourcepub fn set_checksum_type(self, input: Option<ChecksumType>) -> Self
pub fn set_checksum_type(self, input: Option<ChecksumType>) -> Self
The type of checksum used.
Sourcepub fn get_checksum_type(&self) -> &Option<ChecksumType>
pub fn get_checksum_type(&self) -> &Option<ChecksumType>
The type of checksum used.
Sourcepub fn server_side_encryption(self, input: ServerSideEncryption) -> Self
pub fn server_side_encryption(self, input: ServerSideEncryption) -> Self
The server-side encryption algorithm used to encrypt the annotation.
Sourcepub fn set_server_side_encryption(
self,
input: Option<ServerSideEncryption>,
) -> Self
pub fn set_server_side_encryption( self, input: Option<ServerSideEncryption>, ) -> Self
The server-side encryption algorithm used to encrypt the annotation.
Sourcepub fn get_server_side_encryption(&self) -> &Option<ServerSideEncryption>
pub fn get_server_side_encryption(&self) -> &Option<ServerSideEncryption>
The server-side encryption algorithm used to encrypt the annotation.
Sourcepub fn request_charged(self, input: RequestCharged) -> Self
pub fn request_charged(self, input: RequestCharged) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
pub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_charged(&self) -> &Option<RequestCharged>
pub fn get_request_charged(&self) -> &Option<RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn build(self) -> PutObjectAnnotationOutput
pub fn build(self) -> PutObjectAnnotationOutput
Consumes the builder and constructs a PutObjectAnnotationOutput.