#[non_exhaustive]pub enum PutObjectAnnotationError {
AnnotationLimitExceeded(AnnotationLimitExceeded),
AnnotationNameTooLong(AnnotationNameTooLong),
InvalidAnnotationName(InvalidAnnotationName),
InvalidRequest(InvalidRequest),
NoSuchBucket(NoSuchBucket),
NoSuchKey(NoSuchKey),
UnsupportedMediaType(UnsupportedMediaType),
Unhandled(Unhandled),
}Expand description
Error type for the PutObjectAnnotationError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AnnotationLimitExceeded(AnnotationLimitExceeded)
The request would exceed the maximum number of annotations allowed per object.
AnnotationNameTooLong(AnnotationNameTooLong)
The annotation name exceeds 512 bytes.
InvalidAnnotationName(InvalidAnnotationName)
The annotation name you provided is invalid.
InvalidRequest(InvalidRequest)
A parameter or header in your request isn't valid. For details, see the description of this API operation.
NoSuchBucket(NoSuchBucket)
The specified bucket does not exist.
NoSuchKey(NoSuchKey)
The specified key does not exist.
UnsupportedMediaType(UnsupportedMediaType)
The annotation payload is not valid UTF-8 encoded text.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl PutObjectAnnotationError
impl PutObjectAnnotationError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the PutObjectAnnotationError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the PutObjectAnnotationError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_annotation_limit_exceeded(&self) -> bool
pub fn is_annotation_limit_exceeded(&self) -> bool
Returns true if the error kind is PutObjectAnnotationError::AnnotationLimitExceeded.
Sourcepub fn is_annotation_name_too_long(&self) -> bool
pub fn is_annotation_name_too_long(&self) -> bool
Returns true if the error kind is PutObjectAnnotationError::AnnotationNameTooLong.
Sourcepub fn is_invalid_annotation_name(&self) -> bool
pub fn is_invalid_annotation_name(&self) -> bool
Returns true if the error kind is PutObjectAnnotationError::InvalidAnnotationName.
Sourcepub fn is_invalid_request(&self) -> bool
pub fn is_invalid_request(&self) -> bool
Returns true if the error kind is PutObjectAnnotationError::InvalidRequest.
Sourcepub fn is_no_such_bucket(&self) -> bool
pub fn is_no_such_bucket(&self) -> bool
Returns true if the error kind is PutObjectAnnotationError::NoSuchBucket.
Sourcepub fn is_no_such_key(&self) -> bool
pub fn is_no_such_key(&self) -> bool
Returns true if the error kind is PutObjectAnnotationError::NoSuchKey.
Sourcepub fn is_unsupported_media_type(&self) -> bool
pub fn is_unsupported_media_type(&self) -> bool
Returns true if the error kind is PutObjectAnnotationError::UnsupportedMediaType.