PutObjectAnnotationInput

Struct PutObjectAnnotationInput 

#[non_exhaustive]
pub struct PutObjectAnnotationInput {
Show 20 fields pub bucket: Option<String>, pub key: Option<String>, pub version_id: Option<String>, pub annotation_name: Option<String>, pub annotation_payload: ByteStream, pub object_if_match: Option<String>, pub checksum_algorithm: Option<ChecksumAlgorithm>, pub checksum_crc32: Option<String>, pub checksum_crc32_c: Option<String>, pub checksum_crc64_nvme: Option<String>, pub checksum_sha1: Option<String>, pub checksum_sha256: Option<String>, pub checksum_sha512: Option<String>, pub checksum_md5: Option<String>, pub checksum_xxhash64: Option<String>, pub checksum_xxhash3: Option<String>, pub checksum_xxhash128: Option<String>, pub content_md5: Option<String>, pub request_payer: Option<RequestPayer>, pub expected_bucket_owner: Option<String>,
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
bucket: Option<String>

The name of the bucket that contains the object.

key: Option<String>

The object key.

version_id: Option<String>

The version ID of the object to attach the annotation to.

annotation_name: Option<String>

The name of the annotation.

Length Constraints: Minimum length of 1. Maximum length of 512 bytes.

annotation_payload: ByteStream

The annotation payload. Must be between 1 byte and 1 MiB in size, and must be valid UTF-8 encoded text. If the payload contains invalid UTF-8 bytes, the request fails with HTTP 415 (Unsupported Media Type). To store binary data, encode the payload using Base64 before uploading.

object_if_match: Option<String>

If specified, the operation only succeeds if the object's ETag matches the provided value.

checksum_algorithm: Option<ChecksumAlgorithm>

The checksum algorithm to use. Supported values: CRC32, CRC32C, CRC64NVME, SHA1, SHA256, SHA512, MD5, XXHASH64, XXHASH3, XXHASH128.

checksum_crc32: Option<String>

Base64-encoded CRC32 checksum of the annotation payload.

checksum_crc32_c: Option<String>

Base64-encoded CRC32C checksum of the annotation payload.

checksum_crc64_nvme: Option<String>

Base64-encoded CRC64NVME checksum of the annotation payload.

checksum_sha1: Option<String>

Base64-encoded SHA1 checksum of the annotation payload.

checksum_sha256: Option<String>

Base64-encoded SHA256 checksum of the annotation payload.

checksum_sha512: Option<String>

Base64-encoded SHA512 checksum of the annotation payload.

checksum_md5: Option<String>

Base64-encoded MD5 checksum of the annotation payload.

checksum_xxhash64: Option<String>

Base64-encoded XXHASH64 checksum of the annotation payload.

checksum_xxhash3: Option<String>

Base64-encoded XXHASH3 checksum of the annotation payload.

checksum_xxhash128: Option<String>

Base64-encoded XXHASH128 checksum of the annotation payload.

content_md5: Option<String>

Base64-encoded MD5 digest of the message.

request_payer: Option<RequestPayer>

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

expected_bucket_owner: Option<String>

The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.

Implementations

Source

impl PutObjectAnnotationInput

pub fn bucket(&self) -> Option<&str>

The name of the bucket that contains the object.

pub fn key(&self) -> Option<&str>

The object key.

pub fn version_id(&self) -> Option<&str>

The version ID of the object to attach the annotation to.

pub fn annotation_name(&self) -> Option<&str>

The name of the annotation.

Length Constraints: Minimum length of 1. Maximum length of 512 bytes.

pub fn annotation_payload(&self) -> &ByteStream

The annotation payload. Must be between 1 byte and 1 MiB in size, and must be valid UTF-8 encoded text. If the payload contains invalid UTF-8 bytes, the request fails with HTTP 415 (Unsupported Media Type). To store binary data, encode the payload using Base64 before uploading.

pub fn object_if_match(&self) -> Option<&str>

If specified, the operation only succeeds if the object's ETag matches the provided value.

pub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>

The checksum algorithm to use. Supported values: CRC32, CRC32C, CRC64NVME, SHA1, SHA256, SHA512, MD5, XXHASH64, XXHASH3, XXHASH128.

pub fn checksum_crc32(&self) -> Option<&str>

Base64-encoded CRC32 checksum of the annotation payload.

pub fn checksum_crc32_c(&self) -> Option<&str>

Base64-encoded CRC32C checksum of the annotation payload.

pub fn checksum_crc64_nvme(&self) -> Option<&str>

Base64-encoded CRC64NVME checksum of the annotation payload.

pub fn checksum_sha1(&self) -> Option<&str>

Base64-encoded SHA1 checksum of the annotation payload.

pub fn checksum_sha256(&self) -> Option<&str>

Base64-encoded SHA256 checksum of the annotation payload.

pub fn checksum_sha512(&self) -> Option<&str>

Base64-encoded SHA512 checksum of the annotation payload.

pub fn checksum_md5(&self) -> Option<&str>

Base64-encoded MD5 checksum of the annotation payload.

pub fn checksum_xxhash64(&self) -> Option<&str>

Base64-encoded XXHASH64 checksum of the annotation payload.

pub fn checksum_xxhash3(&self) -> Option<&str>

Base64-encoded XXHASH3 checksum of the annotation payload.

pub fn checksum_xxhash128(&self) -> Option<&str>

Base64-encoded XXHASH128 checksum of the annotation payload.

pub fn content_md5(&self) -> Option<&str>

Base64-encoded MD5 digest of the message.

pub fn request_payer(&self) -> Option<&RequestPayer>

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

pub fn expected_bucket_owner(&self) -> Option<&str>

The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.

Source

impl PutObjectAnnotationInput

pub fn builder() -> PutObjectAnnotationInputBuilder

Creates a new builder-style object to manufacture PutObjectAnnotationInput.