#[non_exhaustive]pub struct UpdateBucketMetadataAnnotationTableConfigurationInputBuilder { /* private fields */ }Expand description
A builder for UpdateBucketMetadataAnnotationTableConfigurationInput.
Implementations
Sourceimpl UpdateBucketMetadataAnnotationTableConfigurationInputBuilder
impl UpdateBucketMetadataAnnotationTableConfigurationInputBuilder
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket whose annotation table configuration to update.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket whose annotation table configuration to update.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket whose annotation table configuration to update.
Sourcepub fn content_md5(self, input: impl Into<String>) -> Self
pub fn content_md5(self, input: impl Into<String>) -> Self
Base64-encoded MD5 digest of the message body.
Sourcepub fn set_content_md5(self, input: Option<String>) -> Self
pub fn set_content_md5(self, input: Option<String>) -> Self
Base64-encoded MD5 digest of the message body.
Sourcepub fn get_content_md5(&self) -> &Option<String>
pub fn get_content_md5(&self) -> &Option<String>
Base64-encoded MD5 digest of the message body.
Sourcepub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
pub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
Checksum algorithm for the request payload.
Sourcepub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
pub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
Checksum algorithm for the request payload.
Sourcepub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
pub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
Checksum algorithm for the request payload.
Sourcepub fn annotation_table_configuration(
self,
input: AnnotationTableConfigurationUpdates,
) -> Self
pub fn annotation_table_configuration( self, input: AnnotationTableConfigurationUpdates, ) -> Self
The annotation table configuration updates to apply.
This field is required.Sourcepub fn set_annotation_table_configuration(
self,
input: Option<AnnotationTableConfigurationUpdates>,
) -> Self
pub fn set_annotation_table_configuration( self, input: Option<AnnotationTableConfigurationUpdates>, ) -> Self
The annotation table configuration updates to apply.
Sourcepub fn get_annotation_table_configuration(
&self,
) -> &Option<AnnotationTableConfigurationUpdates>
pub fn get_annotation_table_configuration( &self, ) -> &Option<AnnotationTableConfigurationUpdates>
The annotation table configuration updates to apply.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner.
Sourcepub fn build(
self,
) -> Result<UpdateBucketMetadataAnnotationTableConfigurationInput, BuildError>
pub fn build( self, ) -> Result<UpdateBucketMetadataAnnotationTableConfigurationInput, BuildError>
Consumes the builder and constructs a UpdateBucketMetadataAnnotationTableConfigurationInput.
Sourceimpl UpdateBucketMetadataAnnotationTableConfigurationInputBuilder
impl UpdateBucketMetadataAnnotationTableConfigurationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateBucketMetadataAnnotationTableConfigurationOutput, SdkError<UpdateBucketMetadataAnnotationTableConfigurationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateBucketMetadataAnnotationTableConfigurationOutput, SdkError<UpdateBucketMetadataAnnotationTableConfigurationError, HttpResponse>>
Sends a request with this input using the given client.