#[non_exhaustive]pub struct UpdateBucketMetadataAnnotationTableConfigurationInput {
pub bucket: Option<String>,
pub content_md5: Option<String>,
pub checksum_algorithm: Option<ChecksumAlgorithm>,
pub annotation_table_configuration: Option<AnnotationTableConfigurationUpdates>,
pub expected_bucket_owner: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the bucket whose annotation table configuration to update.
content_md5: Option<String>Base64-encoded MD5 digest of the message body.
checksum_algorithm: Option<ChecksumAlgorithm>Checksum algorithm for the request payload.
annotation_table_configuration: Option<AnnotationTableConfigurationUpdates>The annotation table configuration updates to apply.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner.
Implementations
Sourceimpl UpdateBucketMetadataAnnotationTableConfigurationInput
impl UpdateBucketMetadataAnnotationTableConfigurationInput
Sourcepub fn bucket(&self) -> Option<&str>
pub fn bucket(&self) -> Option<&str>
The name of the bucket whose annotation table configuration to update.
Sourcepub fn content_md5(&self) -> Option<&str>
pub fn content_md5(&self) -> Option<&str>
Base64-encoded MD5 digest of the message body.
Sourcepub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
pub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
Checksum algorithm for the request payload.
Sourcepub fn annotation_table_configuration(
&self,
) -> Option<&AnnotationTableConfigurationUpdates>
pub fn annotation_table_configuration( &self, ) -> Option<&AnnotationTableConfigurationUpdates>
The annotation table configuration updates to apply.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner.
Sourceimpl UpdateBucketMetadataAnnotationTableConfigurationInput
impl UpdateBucketMetadataAnnotationTableConfigurationInput
Sourcepub fn builder() -> UpdateBucketMetadataAnnotationTableConfigurationInputBuilder
pub fn builder() -> UpdateBucketMetadataAnnotationTableConfigurationInputBuilder
Creates a new builder-style object to manufacture UpdateBucketMetadataAnnotationTableConfigurationInput.