AnnotationEntryBuilder

Struct AnnotationEntryBuilder 

#[non_exhaustive]
pub struct AnnotationEntryBuilder { /* private fields */ }
A builder for AnnotationEntry.

Implementations

Source

impl AnnotationEntryBuilder

pub fn annotation_name(self, input: impl Into<String>) -> Self

The name of the annotation.

This field is required.
pub fn set_annotation_name(self, input: Option<String>) -> Self

The name of the annotation.

pub fn get_annotation_name(&self) -> &Option<String>

The name of the annotation.

pub fn last_modified(self, input: DateTime) -> Self

The date and time the annotation was last modified.

This field is required.
pub fn set_last_modified(self, input: Option<DateTime>) -> Self

The date and time the annotation was last modified.

pub fn get_last_modified(&self) -> &Option<DateTime>

The date and time the annotation was last modified.

pub fn e_tag(self, input: impl Into<String>) -> Self

The entity tag of the annotation.

pub fn set_e_tag(self, input: Option<String>) -> Self

The entity tag of the annotation.

pub fn get_e_tag(&self) -> &Option<String>

The entity tag of the annotation.

pub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self

Appends an item to checksum_algorithm.

To override the contents of this collection use set_checksum_algorithm.

The checksum algorithm used for the annotation.

pub fn set_checksum_algorithm( self, input: Option<Vec<ChecksumAlgorithm>>, ) -> Self

The checksum algorithm used for the annotation.

pub fn get_checksum_algorithm(&self) -> &Option<Vec<ChecksumAlgorithm>>

The checksum algorithm used for the annotation.

pub fn size(self, input: i64) -> Self

The size of the annotation payload, in bytes.

This field is required.
pub fn set_size(self, input: Option<i64>) -> Self

The size of the annotation payload, in bytes.

pub fn get_size(&self) -> &Option<i64>

The size of the annotation payload, in bytes.

pub fn replication_status(self, input: ReplicationStatus) -> Self

The replication status of the annotation.

pub fn set_replication_status(self, input: Option<ReplicationStatus>) -> Self

The replication status of the annotation.

pub fn get_replication_status(&self) -> &Option<ReplicationStatus>

The replication status of the annotation.

pub fn build(self) -> Result<AnnotationEntry, BuildError>

Consumes the builder and constructs a AnnotationEntry. This method will fail if any of the following fields are not set: