AnnotationTableConfigurationResultBuilder

Struct AnnotationTableConfigurationResultBuilder 

#[non_exhaustive]
pub struct AnnotationTableConfigurationResultBuilder { /* private fields */ }
Implementations

Source

impl AnnotationTableConfigurationResultBuilder

pub fn configuration_state(self, input: AnnotationConfigurationState) -> Self

The current configuration state of the annotation table.

This field is required.
pub fn set_configuration_state( self, input: Option<AnnotationConfigurationState>, ) -> Self

The current configuration state of the annotation table.

pub fn get_configuration_state(&self) -> &Option<AnnotationConfigurationState>

The current configuration state of the annotation table.

pub fn table_status(self, input: impl Into<String>) -> Self

The provisioning status of the annotation table. Possible values: CREATING, BACKFILLING, ACTIVE, FAILED.

pub fn set_table_status(self, input: Option<String>) -> Self

The provisioning status of the annotation table. Possible values: CREATING, BACKFILLING, ACTIVE, FAILED.

pub fn get_table_status(&self) -> &Option<String>

The provisioning status of the annotation table. Possible values: CREATING, BACKFILLING, ACTIVE, FAILED.

pub fn error(self, input: ErrorDetails) -> Self

If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.

If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.

pub fn set_error(self, input: Option<ErrorDetails>) -> Self

If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.

If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.

pub fn get_error(&self) -> &Option<ErrorDetails>

If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.

If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.

pub fn table_name(self, input: impl Into<String>) -> Self

The name of the annotation table.

pub fn set_table_name(self, input: Option<String>) -> Self

The name of the annotation table.

pub fn get_table_name(&self) -> &Option<String>

The name of the annotation table.

pub fn table_arn(self, input: impl Into<String>) -> Self

The ARN of the annotation table.

pub fn set_table_arn(self, input: Option<String>) -> Self

The ARN of the annotation table.

pub fn get_table_arn(&self) -> &Option<String>

The ARN of the annotation table.

pub fn role(self, input: impl Into<String>) -> Self

The ARN of the IAM role associated with the annotation table.

pub fn set_role(self, input: Option<String>) -> Self

The ARN of the IAM role associated with the annotation table.

pub fn get_role(&self) -> &Option<String>

The ARN of the IAM role associated with the annotation table.

pub fn build(self) -> Result<AnnotationTableConfigurationResult, BuildError>

Consumes the builder and constructs a AnnotationTableConfigurationResult. This method will fail if any of the following fields are not set: