#[non_exhaustive]pub struct EventHoldDurationBuilder { /* private fields */ }Expand description
A builder for EventHoldDuration.
Implementations
Sourceimpl EventHoldDurationBuilder
impl EventHoldDurationBuilder
Sourcepub fn days(self, input: i32) -> Self
pub fn days(self, input: i32) -> Self
The number of days for the event hold duration. The minimum value is 1 and the maximum value is 36,500.
Sourcepub fn set_days(self, input: Option<i32>) -> Self
pub fn set_days(self, input: Option<i32>) -> Self
The number of days for the event hold duration. The minimum value is 1 and the maximum value is 36,500.
Sourcepub fn get_days(&self) -> &Option<i32>
pub fn get_days(&self) -> &Option<i32>
The number of days for the event hold duration. The minimum value is 1 and the maximum value is 36,500.
Sourcepub fn years(self, input: i32) -> Self
pub fn years(self, input: i32) -> Self
The number of years for the event hold duration. The minimum value is 1 and the maximum value is 100.
Sourcepub fn set_years(self, input: Option<i32>) -> Self
pub fn set_years(self, input: Option<i32>) -> Self
The number of years for the event hold duration. The minimum value is 1 and the maximum value is 100.
Sourcepub fn get_years(&self) -> &Option<i32>
pub fn get_years(&self) -> &Option<i32>
The number of years for the event hold duration. The minimum value is 1 and the maximum value is 100.
Sourcepub fn build(self) -> EventHoldDuration
pub fn build(self) -> EventHoldDuration
Consumes the builder and constructs a EventHoldDuration.