#[non_exhaustive]pub struct MetadataConfigurationResultBuilder { /* private fields */ }Expand description
A builder for MetadataConfigurationResult.
Implementations
Sourceimpl MetadataConfigurationResultBuilder
impl MetadataConfigurationResultBuilder
Sourcepub fn destination_result(self, input: DestinationResult) -> Self
pub fn destination_result(self, input: DestinationResult) -> Self
The destination settings for a metadata configuration.
This field is required.Sourcepub fn set_destination_result(self, input: Option<DestinationResult>) -> Self
pub fn set_destination_result(self, input: Option<DestinationResult>) -> Self
The destination settings for a metadata configuration.
Sourcepub fn get_destination_result(&self) -> &Option<DestinationResult>
pub fn get_destination_result(&self) -> &Option<DestinationResult>
The destination settings for a metadata configuration.
Sourcepub fn journal_table_configuration_result(
self,
input: JournalTableConfigurationResult,
) -> Self
pub fn journal_table_configuration_result( self, input: JournalTableConfigurationResult, ) -> Self
The journal table configuration for a metadata configuration.
Sourcepub fn set_journal_table_configuration_result(
self,
input: Option<JournalTableConfigurationResult>,
) -> Self
pub fn set_journal_table_configuration_result( self, input: Option<JournalTableConfigurationResult>, ) -> Self
The journal table configuration for a metadata configuration.
Sourcepub fn get_journal_table_configuration_result(
&self,
) -> &Option<JournalTableConfigurationResult>
pub fn get_journal_table_configuration_result( &self, ) -> &Option<JournalTableConfigurationResult>
The journal table configuration for a metadata configuration.
Sourcepub fn inventory_table_configuration_result(
self,
input: InventoryTableConfigurationResult,
) -> Self
pub fn inventory_table_configuration_result( self, input: InventoryTableConfigurationResult, ) -> Self
The inventory table configuration for a metadata configuration.
Sourcepub fn set_inventory_table_configuration_result(
self,
input: Option<InventoryTableConfigurationResult>,
) -> Self
pub fn set_inventory_table_configuration_result( self, input: Option<InventoryTableConfigurationResult>, ) -> Self
The inventory table configuration for a metadata configuration.
Sourcepub fn get_inventory_table_configuration_result(
&self,
) -> &Option<InventoryTableConfigurationResult>
pub fn get_inventory_table_configuration_result( &self, ) -> &Option<InventoryTableConfigurationResult>
The inventory table configuration for a metadata configuration.
Sourcepub fn annotation_table_configuration_result(
self,
input: AnnotationTableConfigurationResult,
) -> Self
pub fn annotation_table_configuration_result( self, input: AnnotationTableConfigurationResult, ) -> Self
The annotation table configuration result, if an annotation table is configured.
Sourcepub fn set_annotation_table_configuration_result(
self,
input: Option<AnnotationTableConfigurationResult>,
) -> Self
pub fn set_annotation_table_configuration_result( self, input: Option<AnnotationTableConfigurationResult>, ) -> Self
The annotation table configuration result, if an annotation table is configured.
Sourcepub fn get_annotation_table_configuration_result(
&self,
) -> &Option<AnnotationTableConfigurationResult>
pub fn get_annotation_table_configuration_result( &self, ) -> &Option<AnnotationTableConfigurationResult>
The annotation table configuration result, if an annotation table is configured.
Sourcepub fn build(self) -> MetadataConfigurationResult
pub fn build(self) -> MetadataConfigurationResult
Consumes the builder and constructs a MetadataConfigurationResult.