#[non_exhaustive]pub struct ObjectLockRetentionBuilder { /* private fields */ }Expand description
A builder for ObjectLockRetention.
Implementations
Sourceimpl ObjectLockRetentionBuilder
impl ObjectLockRetentionBuilder
Sourcepub fn mode(self, input: ObjectLockRetentionMode) -> Self
pub fn mode(self, input: ObjectLockRetentionMode) -> Self
Indicates the Retention mode for the specified object.
Sourcepub fn set_mode(self, input: Option<ObjectLockRetentionMode>) -> Self
pub fn set_mode(self, input: Option<ObjectLockRetentionMode>) -> Self
Indicates the Retention mode for the specified object.
Sourcepub fn get_mode(&self) -> &Option<ObjectLockRetentionMode>
pub fn get_mode(&self) -> &Option<ObjectLockRetentionMode>
Indicates the Retention mode for the specified object.
Sourcepub fn retain_until_date(self, input: DateTime) -> Self
pub fn retain_until_date(self, input: DateTime) -> Self
The date on which this Object Lock Retention will expire.
Sourcepub fn set_retain_until_date(self, input: Option<DateTime>) -> Self
pub fn set_retain_until_date(self, input: Option<DateTime>) -> Self
The date on which this Object Lock Retention will expire.
Sourcepub fn get_retain_until_date(&self) -> &Option<DateTime>
pub fn get_retain_until_date(&self) -> &Option<DateTime>
The date on which this Object Lock Retention will expire.
Sourcepub fn event_hold(self, input: ObjectLockEventHold) -> Self
pub fn event_hold(self, input: ObjectLockEventHold) -> Self
The event hold status for the object. Set to ON to enable an event hold or OFF to disable it.
Sourcepub fn set_event_hold(self, input: Option<ObjectLockEventHold>) -> Self
pub fn set_event_hold(self, input: Option<ObjectLockEventHold>) -> Self
The event hold status for the object. Set to ON to enable an event hold or OFF to disable it.
Sourcepub fn get_event_hold(&self) -> &Option<ObjectLockEventHold>
pub fn get_event_hold(&self) -> &Option<ObjectLockEventHold>
The event hold status for the object. Set to ON to enable an event hold or OFF to disable it.
Sourcepub fn event_hold_duration(self, input: EventHoldDuration) -> Self
pub fn event_hold_duration(self, input: EventHoldDuration) -> Self
The event hold duration for the object. Specifies how long the object remains protected after the event hold is released.
Sourcepub fn set_event_hold_duration(self, input: Option<EventHoldDuration>) -> Self
pub fn set_event_hold_duration(self, input: Option<EventHoldDuration>) -> Self
The event hold duration for the object. Specifies how long the object remains protected after the event hold is released.
Sourcepub fn get_event_hold_duration(&self) -> &Option<EventHoldDuration>
pub fn get_event_hold_duration(&self) -> &Option<EventHoldDuration>
The event hold duration for the object. Specifies how long the object remains protected after the event hold is released.
Sourcepub fn build(self) -> ObjectLockRetention
pub fn build(self) -> ObjectLockRetention
Consumes the builder and constructs a ObjectLockRetention.