ObjectLockRuleBuilder

Struct ObjectLockRuleBuilder 

#[non_exhaustive]
pub struct ObjectLockRuleBuilder { /* private fields */ }
A builder for ObjectLockRule.

Implementations

Source

impl ObjectLockRuleBuilder

pub fn default_retention(self, input: DefaultRetention) -> Self

The default Object Lock retention settings for new objects in this bucket. You can specify:

  • A default retention period, by using Days or Years.

  • A default event hold duration, by using DefaultEventHold. This setting also uses days or years.

You can set one or both. You cannot use days and years in the same setting.

pub fn set_default_retention(self, input: Option<DefaultRetention>) -> Self

The default Object Lock retention settings for new objects in this bucket. You can specify:

  • A default retention period, by using Days or Years.

  • A default event hold duration, by using DefaultEventHold. This setting also uses days or years.

You can set one or both. You cannot use days and years in the same setting.

pub fn get_default_retention(&self) -> &Option<DefaultRetention>

The default Object Lock retention settings for new objects in this bucket. You can specify:

  • A default retention period, by using Days or Years.

  • A default event hold duration, by using DefaultEventHold. This setting also uses days or years.

You can set one or both. You cannot use days and years in the same setting.

pub fn build(self) -> ObjectLockRule

Consumes the builder and constructs a ObjectLockRule.