#[non_exhaustive]pub enum ObjectEncryption {
Ssekms(SsekmsEncryption),
#[non_exhaustive] Unknown,
}Expand description
The updated server-side encryption type for this object. The UpdateObjectEncryption operation supports the SSE-S3 and SSE-KMS encryption types.
Valid Values: SSES3 | SSEKMS
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Ssekms(SsekmsEncryption)
Specifies to update the object encryption type to server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl ObjectEncryption
impl ObjectEncryption
Sourcepub fn as_ssekms(&self) -> Result<&SsekmsEncryption, &Self>
pub fn as_ssekms(&self) -> Result<&SsekmsEncryption, &Self>
Tries to convert the enum instance into Ssekms, extracting the inner SsekmsEncryption.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.