AnnotationTableConfigurationResult

Struct AnnotationTableConfigurationResult 

#[non_exhaustive]
pub struct AnnotationTableConfigurationResult { pub configuration_state: AnnotationConfigurationState, pub table_status: Option<String>, pub error: Option<ErrorDetails>, pub table_name: Option<String>, pub table_arn: Option<String>, pub role: Option<String>, }
Contains the current state of the annotation table associated with a bucket's Amazon S3 Metadata configuration, including its provisioning status and identifiers.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
configuration_state: AnnotationConfigurationState

The current configuration state of the annotation table.

table_status: Option<String>

The provisioning status of the annotation table. Possible values: CREATING, BACKFILLING, ACTIVE, FAILED.

error: Option<ErrorDetails>

If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.

If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.

table_name: Option<String>

The name of the annotation table.

table_arn: Option<String>

The ARN of the annotation table.

role: Option<String>

The ARN of the IAM role associated with the annotation table.

Implementations

Source

impl AnnotationTableConfigurationResult

pub fn configuration_state(&self) -> &AnnotationConfigurationState

The current configuration state of the annotation table.

pub fn table_status(&self) -> Option<&str>

The provisioning status of the annotation table. Possible values: CREATING, BACKFILLING, ACTIVE, FAILED.

pub fn error(&self) -> Option<&ErrorDetails>

If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.

If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.

pub fn table_name(&self) -> Option<&str>

The name of the annotation table.

pub fn table_arn(&self) -> Option<&str>

The ARN of the annotation table.

pub fn role(&self) -> Option<&str>

The ARN of the IAM role associated with the annotation table.

Source

impl AnnotationTableConfigurationResult

pub fn builder() -> AnnotationTableConfigurationResultBuilder

Creates a new builder-style object to manufacture AnnotationTableConfigurationResult.