DefaultRetention

Struct DefaultRetention 

#[non_exhaustive]
pub struct DefaultRetention { pub mode: Option<ObjectLockRetentionMode>, pub days: Option<i32>, pub years: Option<i32>, pub default_event_hold: Option<EventHoldDuration>, }
The container element for optionally specifying the default Object Lock retention settings for new objects placed in the specified bucket.

  • The DefaultRetention settings require both a mode and a period.

  • The DefaultRetention period can be either Days or Years but you must select one. You cannot specify Days and Years at the same time.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
mode: Option<ObjectLockRetentionMode>

The default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Must be used with either Days or Years.

days: Option<i32>

The number of days that you want to specify for the default retention period. Must be used with Mode.

years: Option<i32>

The number of years that you want to specify for the default retention period. Must be used with Mode.

default_event_hold: Option<EventHoldDuration>

The default event hold duration to be applied to new objects placed in the specified bucket. When configured, new objects will automatically have an event hold enabled with this duration.

Implementations

Source

impl DefaultRetention

pub fn mode(&self) -> Option<&ObjectLockRetentionMode>

The default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Must be used with either Days or Years.

pub fn days(&self) -> Option<i32>

The number of days that you want to specify for the default retention period. Must be used with Mode.

pub fn years(&self) -> Option<i32>

The number of years that you want to specify for the default retention period. Must be used with Mode.

pub fn default_event_hold(&self) -> Option<&EventHoldDuration>

The default event hold duration to be applied to new objects placed in the specified bucket. When configured, new objects will automatically have an event hold enabled with this duration.

Source

impl DefaultRetention

pub fn builder() -> DefaultRetentionBuilder

Creates a new builder-style object to manufacture DefaultRetention.