#[non_exhaustive]pub struct EventHoldDuration {
pub days: Option<i32>,
pub years: Option<i32>,
}Expand description
Contains the event hold duration configuration, specified in either days or years.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.days: Option<i32>The number of days for the event hold duration. The minimum value is 1 and the maximum value is 36,500.
years: Option<i32>The number of years for the event hold duration. The minimum value is 1 and the maximum value is 100.
Implementations
Sourceimpl EventHoldDuration
impl EventHoldDuration
Sourcepub fn builder() -> EventHoldDurationBuilder
pub fn builder() -> EventHoldDurationBuilder
Creates a new builder-style object to manufacture EventHoldDuration.