#[non_exhaustive]pub struct ObjectLockRetention {
pub mode: Option<ObjectLockRetentionMode>,
pub retain_until_date: Option<DateTime>,
pub event_hold: Option<ObjectLockEventHold>,
pub event_hold_duration: Option<EventHoldDuration>,
}Expand description
A Retention configuration for an object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mode: Option<ObjectLockRetentionMode>Indicates the Retention mode for the specified object.
retain_until_date: Option<DateTime>The date on which this Object Lock Retention will expire.
event_hold: Option<ObjectLockEventHold>The event hold status for the object. Set to ON to enable an event hold or OFF to disable it.
event_hold_duration: Option<EventHoldDuration>The event hold duration for the object. Specifies how long the object remains protected after the event hold is released.
Implementations
Sourceimpl ObjectLockRetention
impl ObjectLockRetention
Sourcepub fn mode(&self) -> Option<&ObjectLockRetentionMode>
pub fn mode(&self) -> Option<&ObjectLockRetentionMode>
Indicates the Retention mode for the specified object.
Sourcepub fn retain_until_date(&self) -> Option<&DateTime>
pub fn retain_until_date(&self) -> Option<&DateTime>
The date on which this Object Lock Retention will expire.
Sourcepub fn event_hold(&self) -> Option<&ObjectLockEventHold>
pub fn event_hold(&self) -> Option<&ObjectLockEventHold>
The event hold status for the object. Set to ON to enable an event hold or OFF to disable it.
Sourcepub fn event_hold_duration(&self) -> Option<&EventHoldDuration>
pub fn event_hold_duration(&self) -> Option<&EventHoldDuration>
The event hold duration for the object. Specifies how long the object remains protected after the event hold is released.
Sourceimpl ObjectLockRetention
impl ObjectLockRetention
Sourcepub fn builder() -> ObjectLockRetentionBuilder
pub fn builder() -> ObjectLockRetentionBuilder
Creates a new builder-style object to manufacture ObjectLockRetention.