#[non_exhaustive]pub struct ObjectLockRule {
pub default_retention: Option<DefaultRetention>,
}Expand description
The container element for an Object Lock rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.default_retention: Option<DefaultRetention>The default Object Lock retention settings for new objects in this bucket. You can specify:
-
A default retention period, by using
DaysorYears. -
A default event hold duration, by using
DefaultEventHold. This setting also uses days or years.
You can set one or both. You cannot use days and years in the same setting.
Implementations
Sourceimpl ObjectLockRule
impl ObjectLockRule
Sourcepub fn default_retention(&self) -> Option<&DefaultRetention>
pub fn default_retention(&self) -> Option<&DefaultRetention>
The default Object Lock retention settings for new objects in this bucket. You can specify:
-
A default retention period, by using
DaysorYears. -
A default event hold duration, by using
DefaultEventHold. This setting also uses days or years.
You can set one or both. You cannot use days and years in the same setting.
Sourceimpl ObjectLockRule
impl ObjectLockRule
Sourcepub fn builder() -> ObjectLockRuleBuilder
pub fn builder() -> ObjectLockRuleBuilder
Creates a new builder-style object to manufacture ObjectLockRule.