#[non_exhaustive]pub struct Part {Show 14 fields
pub part_number: Option<i32>,
pub last_modified: Option<DateTime>,
pub e_tag: Option<String>,
pub size: Option<i64>,
pub checksum_crc32: Option<String>,
pub checksum_crc32_c: Option<String>,
pub checksum_crc64_nvme: Option<String>,
pub checksum_sha1: Option<String>,
pub checksum_sha256: Option<String>,
pub checksum_sha512: Option<String>,
pub checksum_md5: Option<String>,
pub checksum_xxhash64: Option<String>,
pub checksum_xxhash3: Option<String>,
pub checksum_xxhash128: Option<String>,
}Expand description
Container for elements related to a part.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.part_number: Option<i32>Part number identifying the part. This is a positive integer between 1 and 10,000.
last_modified: Option<DateTime>Date and time at which the part was uploaded.
e_tag: Option<String>Entity tag returned when the part was uploaded.
size: Option<i64>Size in bytes of the uploaded part data.
checksum_crc32: Option<String>The Base64 encoded, 32-bit CRC32 checksum of the part. This checksum is present if the object was uploaded with the CRC32 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_crc32_c: Option<String>The Base64 encoded, 32-bit CRC32C checksum of the part. This checksum is present if the object was uploaded with the CRC32C checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_crc64_nvme: Option<String>The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, CRC64NVME, to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_sha1: Option<String>The Base64 encoded, 160-bit SHA1 checksum of the part. This checksum is present if the object was uploaded with the SHA1 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_sha256: Option<String>The Base64 encoded, 256-bit SHA256 checksum of the part. This checksum is present if the object was uploaded with the SHA256 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_sha512: Option<String>The Base64 encoded, 512-bit SHA512 digest of the part. This checksum is present if the multipart upload request was created with the SHA512 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_md5: Option<String>The Base64 encoded, 128-bit MD5 digest of the part. This checksum is present if the multipart upload request was created with the MD5 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_xxhash64: Option<String>The Base64 encoded, 64-bit XXHASH64 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH64 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_xxhash3: Option<String>The Base64 encoded, 64-bit XXHASH3 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH3 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_xxhash128: Option<String>The Base64 encoded, 128-bit XXHASH128 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH128 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Implementations
Sourceimpl Part
impl Part
Sourcepub fn part_number(&self) -> Option<i32>
pub fn part_number(&self) -> Option<i32>
Part number identifying the part. This is a positive integer between 1 and 10,000.
Sourcepub fn last_modified(&self) -> Option<&DateTime>
pub fn last_modified(&self) -> Option<&DateTime>
Date and time at which the part was uploaded.
Sourcepub fn checksum_crc32(&self) -> Option<&str>
pub fn checksum_crc32(&self) -> Option<&str>
The Base64 encoded, 32-bit CRC32 checksum of the part. This checksum is present if the object was uploaded with the CRC32 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc32_c(&self) -> Option<&str>
pub fn checksum_crc32_c(&self) -> Option<&str>
The Base64 encoded, 32-bit CRC32C checksum of the part. This checksum is present if the object was uploaded with the CRC32C checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc64_nvme(&self) -> Option<&str>
pub fn checksum_crc64_nvme(&self) -> Option<&str>
The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, CRC64NVME, to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha1(&self) -> Option<&str>
pub fn checksum_sha1(&self) -> Option<&str>
The Base64 encoded, 160-bit SHA1 checksum of the part. This checksum is present if the object was uploaded with the SHA1 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha256(&self) -> Option<&str>
pub fn checksum_sha256(&self) -> Option<&str>
The Base64 encoded, 256-bit SHA256 checksum of the part. This checksum is present if the object was uploaded with the SHA256 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha512(&self) -> Option<&str>
pub fn checksum_sha512(&self) -> Option<&str>
The Base64 encoded, 512-bit SHA512 digest of the part. This checksum is present if the multipart upload request was created with the SHA512 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_md5(&self) -> Option<&str>
pub fn checksum_md5(&self) -> Option<&str>
The Base64 encoded, 128-bit MD5 digest of the part. This checksum is present if the multipart upload request was created with the MD5 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_xxhash64(&self) -> Option<&str>
pub fn checksum_xxhash64(&self) -> Option<&str>
The Base64 encoded, 64-bit XXHASH64 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH64 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_xxhash3(&self) -> Option<&str>
pub fn checksum_xxhash3(&self) -> Option<&str>
The Base64 encoded, 64-bit XXHASH3 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH3 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_xxhash128(&self) -> Option<&str>
pub fn checksum_xxhash128(&self) -> Option<&str>
The Base64 encoded, 128-bit XXHASH128 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH128 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.