#[non_exhaustive]pub struct DeleteObjectAnnotationOutput {
pub object_version_id: Option<String>,
pub request_charged: Option<RequestCharged>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.object_version_id: Option<String>The version ID of the object that the annotation was deleted from.
request_charged: Option<RequestCharged>If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Implementations
Sourceimpl DeleteObjectAnnotationOutput
impl DeleteObjectAnnotationOutput
Sourcepub fn object_version_id(&self) -> Option<&str>
pub fn object_version_id(&self) -> Option<&str>
The version ID of the object that the annotation was deleted from.
Sourcepub fn request_charged(&self) -> Option<&RequestCharged>
pub fn request_charged(&self) -> Option<&RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourceimpl DeleteObjectAnnotationOutput
impl DeleteObjectAnnotationOutput
Sourcepub fn builder() -> DeleteObjectAnnotationOutputBuilder
pub fn builder() -> DeleteObjectAnnotationOutputBuilder
Creates a new builder-style object to manufacture DeleteObjectAnnotationOutput.