pub struct GetObjectAnnotationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetObjectAnnotation.
Retrieves an annotation from an Amazon S3 object. To use this operation, you must have the s3:GetObjectAnnotation permission.
If checksum mode is enabled via the x-amz-checksum-mode header, Amazon S3 returns the stored checksum in the response headers for client-side validation.
Annotations are not supported by the following features: S3 Inventory Reports, API Gateway, S3 Storage Lens, Amazon S3 File Gateway, Amazon FSx, S3 on Outposts, and S3 Express One Zone (directory buckets).
The following operations are related to GetObjectAnnotation:
Implementations
Sourceimpl GetObjectAnnotationFluentBuilder
impl GetObjectAnnotationFluentBuilder
Sourcepub fn as_input(&self) -> &GetObjectAnnotationInputBuilder
pub fn as_input(&self) -> &GetObjectAnnotationInputBuilder
Access the GetObjectAnnotation as a reference.
Sourcepub async fn send(
self,
) -> Result<GetObjectAnnotationOutput, SdkError<GetObjectAnnotationError, HttpResponse>>
pub async fn send( self, ) -> Result<GetObjectAnnotationOutput, SdkError<GetObjectAnnotationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetObjectAnnotationOutput, GetObjectAnnotationError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetObjectAnnotationOutput, GetObjectAnnotationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket that contains the object.
Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket that contains the object.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket that contains the object.
Sourcepub fn annotation_name(self, input: impl Into<String>) -> Self
pub fn annotation_name(self, input: impl Into<String>) -> Self
The name of the annotation to retrieve.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
Sourcepub fn set_annotation_name(self, input: Option<String>) -> Self
pub fn set_annotation_name(self, input: Option<String>) -> Self
The name of the annotation to retrieve.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
Sourcepub fn get_annotation_name(&self) -> &Option<String>
pub fn get_annotation_name(&self) -> &Option<String>
The name of the annotation to retrieve.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
Sourcepub fn version_id(self, input: impl Into<String>) -> Self
pub fn version_id(self, input: impl Into<String>) -> Self
The version ID of the object.
Sourcepub fn set_version_id(self, input: Option<String>) -> Self
pub fn set_version_id(self, input: Option<String>) -> Self
The version ID of the object.
Sourcepub fn get_version_id(&self) -> &Option<String>
pub fn get_version_id(&self) -> &Option<String>
The version ID of the object.
Sourcepub fn request_payer(self, input: RequestPayer) -> Self
pub fn request_payer(self, input: RequestPayer) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
pub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_payer(&self) -> &Option<RequestPayer>
pub fn get_request_payer(&self) -> &Option<RequestPayer>
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
Sourcepub fn checksum_mode(self, input: ChecksumMode) -> Self
pub fn checksum_mode(self, input: ChecksumMode) -> Self
Set to ENABLED to validate the checksum of the annotation payload on retrieval.
Sourcepub fn set_checksum_mode(self, input: Option<ChecksumMode>) -> Self
pub fn set_checksum_mode(self, input: Option<ChecksumMode>) -> Self
Set to ENABLED to validate the checksum of the annotation payload on retrieval.
Sourcepub fn get_checksum_mode(&self) -> &Option<ChecksumMode>
pub fn get_checksum_mode(&self) -> &Option<ChecksumMode>
Set to ENABLED to validate the checksum of the annotation payload on retrieval.