#[non_exhaustive]pub struct GetObjectAnnotationInput {
pub bucket: Option<String>,
pub key: Option<String>,
pub annotation_name: Option<String>,
pub version_id: Option<String>,
pub request_payer: Option<RequestPayer>,
pub expected_bucket_owner: Option<String>,
pub checksum_mode: Option<ChecksumMode>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the bucket that contains the object.
key: Option<String>The object key.
annotation_name: Option<String>The name of the annotation to retrieve.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
version_id: Option<String>The version ID of the object.
request_payer: Option<RequestPayer>Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
checksum_mode: Option<ChecksumMode>Set to ENABLED to validate the checksum of the annotation payload on retrieval.
Implementations
Sourceimpl GetObjectAnnotationInput
impl GetObjectAnnotationInput
Sourcepub fn annotation_name(&self) -> Option<&str>
pub fn annotation_name(&self) -> Option<&str>
The name of the annotation to retrieve.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
Sourcepub fn version_id(&self) -> Option<&str>
pub fn version_id(&self) -> Option<&str>
The version ID of the object.
Sourcepub fn request_payer(&self) -> Option<&RequestPayer>
pub fn request_payer(&self) -> Option<&RequestPayer>
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
Sourcepub fn checksum_mode(&self) -> Option<&ChecksumMode>
pub fn checksum_mode(&self) -> Option<&ChecksumMode>
Set to ENABLED to validate the checksum of the annotation payload on retrieval.
Sourceimpl GetObjectAnnotationInput
impl GetObjectAnnotationInput
Sourcepub fn builder() -> GetObjectAnnotationInputBuilder
pub fn builder() -> GetObjectAnnotationInputBuilder
Creates a new builder-style object to manufacture GetObjectAnnotationInput.