#[non_exhaustive]pub struct GetObjectAnnotationOutput {Show 19 fields
pub annotation_payload: ByteStream,
pub object_version_id: Option<String>,
pub last_modified: Option<DateTime>,
pub content_length: Option<i64>,
pub e_tag: Option<String>,
pub checksum_crc32: Option<String>,
pub checksum_crc32_c: Option<String>,
pub checksum_crc64_nvme: Option<String>,
pub checksum_sha1: Option<String>,
pub checksum_sha256: Option<String>,
pub checksum_sha512: Option<String>,
pub checksum_md5: Option<String>,
pub checksum_xxhash64: Option<String>,
pub checksum_xxhash3: Option<String>,
pub checksum_xxhash128: Option<String>,
pub checksum_type: Option<ChecksumType>,
pub server_side_encryption: Option<ServerSideEncryption>,
pub request_charged: Option<RequestCharged>,
pub replication_status: Option<ReplicationStatus>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.annotation_payload: ByteStreamThe annotation payload.
object_version_id: Option<String>The version ID of the object that the annotation is attached to.
last_modified: Option<DateTime>The date and time the annotation was last modified.
content_length: Option<i64>The size of the annotation payload, in bytes.
e_tag: Option<String>The entity tag of the annotation.
checksum_crc32: Option<String>The CRC32 checksum of the annotation payload.
checksum_crc32_c: Option<String>The CRC32C checksum of the annotation payload.
checksum_crc64_nvme: Option<String>The CRC64NVME checksum of the annotation payload.
checksum_sha1: Option<String>The SHA1 checksum of the annotation payload.
checksum_sha256: Option<String>The SHA256 checksum of the annotation payload.
checksum_sha512: Option<String>The SHA512 checksum of the annotation payload.
checksum_md5: Option<String>The MD5 checksum of the annotation payload.
checksum_xxhash64: Option<String>The XXHASH64 checksum of the annotation payload.
checksum_xxhash3: Option<String>The XXHASH3 checksum of the annotation payload.
checksum_xxhash128: Option<String>The XXHASH128 checksum of the annotation payload.
checksum_type: Option<ChecksumType>The type of checksum used.
server_side_encryption: Option<ServerSideEncryption>The server-side encryption algorithm used.
request_charged: Option<RequestCharged>If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
replication_status: Option<ReplicationStatus>The replication status of the annotation. Possible values include PENDING, COMPLETED, FAILED, and REPLICA.
Implementations
Sourceimpl GetObjectAnnotationOutput
impl GetObjectAnnotationOutput
Sourcepub fn annotation_payload(&self) -> &ByteStream
pub fn annotation_payload(&self) -> &ByteStream
The annotation payload.
Sourcepub fn object_version_id(&self) -> Option<&str>
pub fn object_version_id(&self) -> Option<&str>
The version ID of the object that the annotation is attached to.
Sourcepub fn last_modified(&self) -> Option<&DateTime>
pub fn last_modified(&self) -> Option<&DateTime>
The date and time the annotation was last modified.
Sourcepub fn content_length(&self) -> Option<i64>
pub fn content_length(&self) -> Option<i64>
The size of the annotation payload, in bytes.
Sourcepub fn checksum_crc32(&self) -> Option<&str>
pub fn checksum_crc32(&self) -> Option<&str>
The CRC32 checksum of the annotation payload.
Sourcepub fn checksum_crc32_c(&self) -> Option<&str>
pub fn checksum_crc32_c(&self) -> Option<&str>
The CRC32C checksum of the annotation payload.
Sourcepub fn checksum_crc64_nvme(&self) -> Option<&str>
pub fn checksum_crc64_nvme(&self) -> Option<&str>
The CRC64NVME checksum of the annotation payload.
Sourcepub fn checksum_sha1(&self) -> Option<&str>
pub fn checksum_sha1(&self) -> Option<&str>
The SHA1 checksum of the annotation payload.
Sourcepub fn checksum_sha256(&self) -> Option<&str>
pub fn checksum_sha256(&self) -> Option<&str>
The SHA256 checksum of the annotation payload.
Sourcepub fn checksum_sha512(&self) -> Option<&str>
pub fn checksum_sha512(&self) -> Option<&str>
The SHA512 checksum of the annotation payload.
Sourcepub fn checksum_md5(&self) -> Option<&str>
pub fn checksum_md5(&self) -> Option<&str>
The MD5 checksum of the annotation payload.
Sourcepub fn checksum_xxhash64(&self) -> Option<&str>
pub fn checksum_xxhash64(&self) -> Option<&str>
The XXHASH64 checksum of the annotation payload.
Sourcepub fn checksum_xxhash3(&self) -> Option<&str>
pub fn checksum_xxhash3(&self) -> Option<&str>
The XXHASH3 checksum of the annotation payload.
Sourcepub fn checksum_xxhash128(&self) -> Option<&str>
pub fn checksum_xxhash128(&self) -> Option<&str>
The XXHASH128 checksum of the annotation payload.
Sourcepub fn checksum_type(&self) -> Option<&ChecksumType>
pub fn checksum_type(&self) -> Option<&ChecksumType>
The type of checksum used.
Sourcepub fn server_side_encryption(&self) -> Option<&ServerSideEncryption>
pub fn server_side_encryption(&self) -> Option<&ServerSideEncryption>
The server-side encryption algorithm used.
Sourcepub fn request_charged(&self) -> Option<&RequestCharged>
pub fn request_charged(&self) -> Option<&RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn replication_status(&self) -> Option<&ReplicationStatus>
pub fn replication_status(&self) -> Option<&ReplicationStatus>
The replication status of the annotation. Possible values include PENDING, COMPLETED, FAILED, and REPLICA.
Sourceimpl GetObjectAnnotationOutput
impl GetObjectAnnotationOutput
Sourcepub fn builder() -> GetObjectAnnotationOutputBuilder
pub fn builder() -> GetObjectAnnotationOutputBuilder
Creates a new builder-style object to manufacture GetObjectAnnotationOutput.