pub struct ListObjectAnnotationsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListObjectAnnotations.
Lists the annotations attached to an Amazon S3 object. Results are paginated, with a maximum of 1,000 annotations per object. Use the AnnotationPrefix parameter to filter the results by name prefix.
To use this operation, you must have the s3:ListObjectAnnotations permission.
Annotations are not supported by the following features: S3 Inventory Reports, API Gateway, S3 Storage Lens, Amazon S3 File Gateway, Amazon FSx, S3 on Outposts, and S3 Express One Zone (directory buckets).
The following operations are related to ListObjectAnnotations:
Implementations
Sourceimpl ListObjectAnnotationsFluentBuilder
impl ListObjectAnnotationsFluentBuilder
Sourcepub fn as_input(&self) -> &ListObjectAnnotationsInputBuilder
pub fn as_input(&self) -> &ListObjectAnnotationsInputBuilder
Access the ListObjectAnnotations as a reference.
Sourcepub async fn send(
self,
) -> Result<ListObjectAnnotationsOutput, SdkError<ListObjectAnnotationsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListObjectAnnotationsOutput, SdkError<ListObjectAnnotationsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListObjectAnnotationsOutput, ListObjectAnnotationsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListObjectAnnotationsOutput, ListObjectAnnotationsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListObjectAnnotationsPaginator
pub fn into_paginator(self) -> ListObjectAnnotationsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket that contains the object.
Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket that contains the object.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket that contains the object.
Sourcepub fn version_id(self, input: impl Into<String>) -> Self
pub fn version_id(self, input: impl Into<String>) -> Self
The version ID of the object.
Sourcepub fn set_version_id(self, input: Option<String>) -> Self
pub fn set_version_id(self, input: Option<String>) -> Self
The version ID of the object.
Sourcepub fn get_version_id(&self) -> &Option<String>
pub fn get_version_id(&self) -> &Option<String>
The version ID of the object.
Sourcepub fn max_annotation_results(self, input: i32) -> Self
pub fn max_annotation_results(self, input: i32) -> Self
The maximum number of annotations to return in the response. Maximum is 1,000.
Sourcepub fn set_max_annotation_results(self, input: Option<i32>) -> Self
pub fn set_max_annotation_results(self, input: Option<i32>) -> Self
The maximum number of annotations to return in the response. Maximum is 1,000.
Sourcepub fn get_max_annotation_results(&self) -> &Option<i32>
pub fn get_max_annotation_results(&self) -> &Option<i32>
The maximum number of annotations to return in the response. Maximum is 1,000.
Sourcepub fn annotation_prefix(self, input: impl Into<String>) -> Self
pub fn annotation_prefix(self, input: impl Into<String>) -> Self
Filter results to annotations whose name begins with the specified prefix.
Sourcepub fn set_annotation_prefix(self, input: Option<String>) -> Self
pub fn set_annotation_prefix(self, input: Option<String>) -> Self
Filter results to annotations whose name begins with the specified prefix.
Sourcepub fn get_annotation_prefix(&self) -> &Option<String>
pub fn get_annotation_prefix(&self) -> &Option<String>
Filter results to annotations whose name begins with the specified prefix.
Sourcepub fn continuation_token(self, input: impl Into<String>) -> Self
pub fn continuation_token(self, input: impl Into<String>) -> Self
Continuation token returned by a previous request to retrieve the next page.
Sourcepub fn set_continuation_token(self, input: Option<String>) -> Self
pub fn set_continuation_token(self, input: Option<String>) -> Self
Continuation token returned by a previous request to retrieve the next page.
Sourcepub fn get_continuation_token(&self) -> &Option<String>
pub fn get_continuation_token(&self) -> &Option<String>
Continuation token returned by a previous request to retrieve the next page.
Sourcepub fn request_payer(self, input: RequestPayer) -> Self
pub fn request_payer(self, input: RequestPayer) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
pub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_payer(&self) -> &Option<RequestPayer>
pub fn get_request_payer(&self) -> &Option<RequestPayer>
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner.