#[non_exhaustive]pub struct ListObjectAnnotationsInputBuilder { /* private fields */ }Expand description
A builder for ListObjectAnnotationsInput.
Implementations
Sourceimpl ListObjectAnnotationsInputBuilder
impl ListObjectAnnotationsInputBuilder
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket that contains the object.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket that contains the object.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket that contains the object.
Sourcepub fn version_id(self, input: impl Into<String>) -> Self
pub fn version_id(self, input: impl Into<String>) -> Self
The version ID of the object.
Sourcepub fn set_version_id(self, input: Option<String>) -> Self
pub fn set_version_id(self, input: Option<String>) -> Self
The version ID of the object.
Sourcepub fn get_version_id(&self) -> &Option<String>
pub fn get_version_id(&self) -> &Option<String>
The version ID of the object.
Sourcepub fn max_annotation_results(self, input: i32) -> Self
pub fn max_annotation_results(self, input: i32) -> Self
The maximum number of annotations to return in the response. Maximum is 1,000.
Sourcepub fn set_max_annotation_results(self, input: Option<i32>) -> Self
pub fn set_max_annotation_results(self, input: Option<i32>) -> Self
The maximum number of annotations to return in the response. Maximum is 1,000.
Sourcepub fn get_max_annotation_results(&self) -> &Option<i32>
pub fn get_max_annotation_results(&self) -> &Option<i32>
The maximum number of annotations to return in the response. Maximum is 1,000.
Sourcepub fn annotation_prefix(self, input: impl Into<String>) -> Self
pub fn annotation_prefix(self, input: impl Into<String>) -> Self
Filter results to annotations whose name begins with the specified prefix.
Sourcepub fn set_annotation_prefix(self, input: Option<String>) -> Self
pub fn set_annotation_prefix(self, input: Option<String>) -> Self
Filter results to annotations whose name begins with the specified prefix.
Sourcepub fn get_annotation_prefix(&self) -> &Option<String>
pub fn get_annotation_prefix(&self) -> &Option<String>
Filter results to annotations whose name begins with the specified prefix.
Sourcepub fn continuation_token(self, input: impl Into<String>) -> Self
pub fn continuation_token(self, input: impl Into<String>) -> Self
Continuation token returned by a previous request to retrieve the next page.
Sourcepub fn set_continuation_token(self, input: Option<String>) -> Self
pub fn set_continuation_token(self, input: Option<String>) -> Self
Continuation token returned by a previous request to retrieve the next page.
Sourcepub fn get_continuation_token(&self) -> &Option<String>
pub fn get_continuation_token(&self) -> &Option<String>
Continuation token returned by a previous request to retrieve the next page.
Sourcepub fn request_payer(self, input: RequestPayer) -> Self
pub fn request_payer(self, input: RequestPayer) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
pub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_payer(&self) -> &Option<RequestPayer>
pub fn get_request_payer(&self) -> &Option<RequestPayer>
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner.
Sourcepub fn build(self) -> Result<ListObjectAnnotationsInput, BuildError>
pub fn build(self) -> Result<ListObjectAnnotationsInput, BuildError>
Consumes the builder and constructs a ListObjectAnnotationsInput.
Sourceimpl ListObjectAnnotationsInputBuilder
impl ListObjectAnnotationsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListObjectAnnotationsOutput, SdkError<ListObjectAnnotationsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListObjectAnnotationsOutput, SdkError<ListObjectAnnotationsError, HttpResponse>>
Sends a request with this input using the given client.