#[non_exhaustive]pub struct ListObjectAnnotationsInput {
pub bucket: Option<String>,
pub key: Option<String>,
pub version_id: Option<String>,
pub max_annotation_results: Option<i32>,
pub annotation_prefix: Option<String>,
pub continuation_token: Option<String>,
pub request_payer: Option<RequestPayer>,
pub expected_bucket_owner: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the bucket that contains the object.
key: Option<String>The object key.
version_id: Option<String>The version ID of the object.
max_annotation_results: Option<i32>The maximum number of annotations to return in the response. Maximum is 1,000.
annotation_prefix: Option<String>Filter results to annotations whose name begins with the specified prefix.
continuation_token: Option<String>Continuation token returned by a previous request to retrieve the next page.
request_payer: Option<RequestPayer>Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner.
Implementations
Sourceimpl ListObjectAnnotationsInput
impl ListObjectAnnotationsInput
Sourcepub fn version_id(&self) -> Option<&str>
pub fn version_id(&self) -> Option<&str>
The version ID of the object.
Sourcepub fn max_annotation_results(&self) -> Option<i32>
pub fn max_annotation_results(&self) -> Option<i32>
The maximum number of annotations to return in the response. Maximum is 1,000.
Sourcepub fn annotation_prefix(&self) -> Option<&str>
pub fn annotation_prefix(&self) -> Option<&str>
Filter results to annotations whose name begins with the specified prefix.
Sourcepub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
Continuation token returned by a previous request to retrieve the next page.
Sourcepub fn request_payer(&self) -> Option<&RequestPayer>
pub fn request_payer(&self) -> Option<&RequestPayer>
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner.
Sourceimpl ListObjectAnnotationsInput
impl ListObjectAnnotationsInput
Sourcepub fn builder() -> ListObjectAnnotationsInputBuilder
pub fn builder() -> ListObjectAnnotationsInputBuilder
Creates a new builder-style object to manufacture ListObjectAnnotationsInput.