#[non_exhaustive]pub struct ListObjectAnnotationsOutput {
pub annotations: Option<Vec<AnnotationEntry>>,
pub bucket: Option<String>,
pub key: Option<String>,
pub object_version_id: Option<String>,
pub annotation_prefix: Option<String>,
pub max_annotation_results: Option<i32>,
pub annotation_count: Option<i32>,
pub continuation_token: Option<String>,
pub next_continuation_token: Option<String>,
pub request_charged: Option<RequestCharged>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.annotations: Option<Vec<AnnotationEntry>>The list of annotations attached to the object.
bucket: Option<String>The bucket name.
key: Option<String>The object key.
object_version_id: Option<String>The version ID of the object.
annotation_prefix: Option<String>The prefix used to filter the response.
max_annotation_results: Option<i32>The maximum number of annotations returned in the response.
annotation_count: Option<i32>The number of annotations returned.
continuation_token: Option<String>The continuation token used in this request.
next_continuation_token: Option<String>The continuation token to use to retrieve the next page of results.
request_charged: Option<RequestCharged>If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Implementations
Sourceimpl ListObjectAnnotationsOutput
impl ListObjectAnnotationsOutput
Sourcepub fn annotations(&self) -> &[AnnotationEntry]
pub fn annotations(&self) -> &[AnnotationEntry]
The list of annotations attached to the object.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .annotations.is_none().
Sourcepub fn object_version_id(&self) -> Option<&str>
pub fn object_version_id(&self) -> Option<&str>
The version ID of the object.
Sourcepub fn annotation_prefix(&self) -> Option<&str>
pub fn annotation_prefix(&self) -> Option<&str>
The prefix used to filter the response.
Sourcepub fn max_annotation_results(&self) -> Option<i32>
pub fn max_annotation_results(&self) -> Option<i32>
The maximum number of annotations returned in the response.
Sourcepub fn annotation_count(&self) -> Option<i32>
pub fn annotation_count(&self) -> Option<i32>
The number of annotations returned.
Sourcepub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
The continuation token used in this request.
Sourcepub fn next_continuation_token(&self) -> Option<&str>
pub fn next_continuation_token(&self) -> Option<&str>
The continuation token to use to retrieve the next page of results.
Sourcepub fn request_charged(&self) -> Option<&RequestCharged>
pub fn request_charged(&self) -> Option<&RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourceimpl ListObjectAnnotationsOutput
impl ListObjectAnnotationsOutput
Sourcepub fn builder() -> ListObjectAnnotationsOutputBuilder
pub fn builder() -> ListObjectAnnotationsOutputBuilder
Creates a new builder-style object to manufacture ListObjectAnnotationsOutput.