#[non_exhaustive]pub struct PutObjectAnnotationInputBuilder { /* private fields */ }Expand description
A builder for PutObjectAnnotationInput.
Implementations
Sourceimpl PutObjectAnnotationInputBuilder
impl PutObjectAnnotationInputBuilder
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket that contains the object.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket that contains the object.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket that contains the object.
Sourcepub fn version_id(self, input: impl Into<String>) -> Self
pub fn version_id(self, input: impl Into<String>) -> Self
The version ID of the object to attach the annotation to.
Sourcepub fn set_version_id(self, input: Option<String>) -> Self
pub fn set_version_id(self, input: Option<String>) -> Self
The version ID of the object to attach the annotation to.
Sourcepub fn get_version_id(&self) -> &Option<String>
pub fn get_version_id(&self) -> &Option<String>
The version ID of the object to attach the annotation to.
Sourcepub fn annotation_name(self, input: impl Into<String>) -> Self
pub fn annotation_name(self, input: impl Into<String>) -> Self
The name of the annotation.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
This field is required.Sourcepub fn set_annotation_name(self, input: Option<String>) -> Self
pub fn set_annotation_name(self, input: Option<String>) -> Self
The name of the annotation.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
Sourcepub fn get_annotation_name(&self) -> &Option<String>
pub fn get_annotation_name(&self) -> &Option<String>
The name of the annotation.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
Sourcepub fn annotation_payload(self, input: ByteStream) -> Self
pub fn annotation_payload(self, input: ByteStream) -> Self
The annotation payload. Must be between 1 byte and 1 MiB in size, and must be valid UTF-8 encoded text. If the payload contains invalid UTF-8 bytes, the request fails with HTTP 415 (Unsupported Media Type). To store binary data, encode the payload using Base64 before uploading.
This field is required.Sourcepub fn set_annotation_payload(self, input: Option<ByteStream>) -> Self
pub fn set_annotation_payload(self, input: Option<ByteStream>) -> Self
The annotation payload. Must be between 1 byte and 1 MiB in size, and must be valid UTF-8 encoded text. If the payload contains invalid UTF-8 bytes, the request fails with HTTP 415 (Unsupported Media Type). To store binary data, encode the payload using Base64 before uploading.
Sourcepub fn get_annotation_payload(&self) -> &Option<ByteStream>
pub fn get_annotation_payload(&self) -> &Option<ByteStream>
The annotation payload. Must be between 1 byte and 1 MiB in size, and must be valid UTF-8 encoded text. If the payload contains invalid UTF-8 bytes, the request fails with HTTP 415 (Unsupported Media Type). To store binary data, encode the payload using Base64 before uploading.
Sourcepub fn object_if_match(self, input: impl Into<String>) -> Self
pub fn object_if_match(self, input: impl Into<String>) -> Self
If specified, the operation only succeeds if the object's ETag matches the provided value.
Sourcepub fn set_object_if_match(self, input: Option<String>) -> Self
pub fn set_object_if_match(self, input: Option<String>) -> Self
If specified, the operation only succeeds if the object's ETag matches the provided value.
Sourcepub fn get_object_if_match(&self) -> &Option<String>
pub fn get_object_if_match(&self) -> &Option<String>
If specified, the operation only succeeds if the object's ETag matches the provided value.
Sourcepub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
pub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
The checksum algorithm to use. Supported values: CRC32, CRC32C, CRC64NVME, SHA1, SHA256, SHA512, MD5, XXHASH64, XXHASH3, XXHASH128.
Sourcepub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
pub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
The checksum algorithm to use. Supported values: CRC32, CRC32C, CRC64NVME, SHA1, SHA256, SHA512, MD5, XXHASH64, XXHASH3, XXHASH128.
Sourcepub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
pub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
The checksum algorithm to use. Supported values: CRC32, CRC32C, CRC64NVME, SHA1, SHA256, SHA512, MD5, XXHASH64, XXHASH3, XXHASH128.
Sourcepub fn checksum_crc32(self, input: impl Into<String>) -> Self
pub fn checksum_crc32(self, input: impl Into<String>) -> Self
Base64-encoded CRC32 checksum of the annotation payload.
Sourcepub fn set_checksum_crc32(self, input: Option<String>) -> Self
pub fn set_checksum_crc32(self, input: Option<String>) -> Self
Base64-encoded CRC32 checksum of the annotation payload.
Sourcepub fn get_checksum_crc32(&self) -> &Option<String>
pub fn get_checksum_crc32(&self) -> &Option<String>
Base64-encoded CRC32 checksum of the annotation payload.
Sourcepub fn checksum_crc32_c(self, input: impl Into<String>) -> Self
pub fn checksum_crc32_c(self, input: impl Into<String>) -> Self
Base64-encoded CRC32C checksum of the annotation payload.
Sourcepub fn set_checksum_crc32_c(self, input: Option<String>) -> Self
pub fn set_checksum_crc32_c(self, input: Option<String>) -> Self
Base64-encoded CRC32C checksum of the annotation payload.
Sourcepub fn get_checksum_crc32_c(&self) -> &Option<String>
pub fn get_checksum_crc32_c(&self) -> &Option<String>
Base64-encoded CRC32C checksum of the annotation payload.
Sourcepub fn checksum_crc64_nvme(self, input: impl Into<String>) -> Self
pub fn checksum_crc64_nvme(self, input: impl Into<String>) -> Self
Base64-encoded CRC64NVME checksum of the annotation payload.
Sourcepub fn set_checksum_crc64_nvme(self, input: Option<String>) -> Self
pub fn set_checksum_crc64_nvme(self, input: Option<String>) -> Self
Base64-encoded CRC64NVME checksum of the annotation payload.
Sourcepub fn get_checksum_crc64_nvme(&self) -> &Option<String>
pub fn get_checksum_crc64_nvme(&self) -> &Option<String>
Base64-encoded CRC64NVME checksum of the annotation payload.
Sourcepub fn checksum_sha1(self, input: impl Into<String>) -> Self
pub fn checksum_sha1(self, input: impl Into<String>) -> Self
Base64-encoded SHA1 checksum of the annotation payload.
Sourcepub fn set_checksum_sha1(self, input: Option<String>) -> Self
pub fn set_checksum_sha1(self, input: Option<String>) -> Self
Base64-encoded SHA1 checksum of the annotation payload.
Sourcepub fn get_checksum_sha1(&self) -> &Option<String>
pub fn get_checksum_sha1(&self) -> &Option<String>
Base64-encoded SHA1 checksum of the annotation payload.
Sourcepub fn checksum_sha256(self, input: impl Into<String>) -> Self
pub fn checksum_sha256(self, input: impl Into<String>) -> Self
Base64-encoded SHA256 checksum of the annotation payload.
Sourcepub fn set_checksum_sha256(self, input: Option<String>) -> Self
pub fn set_checksum_sha256(self, input: Option<String>) -> Self
Base64-encoded SHA256 checksum of the annotation payload.
Sourcepub fn get_checksum_sha256(&self) -> &Option<String>
pub fn get_checksum_sha256(&self) -> &Option<String>
Base64-encoded SHA256 checksum of the annotation payload.
Sourcepub fn checksum_sha512(self, input: impl Into<String>) -> Self
pub fn checksum_sha512(self, input: impl Into<String>) -> Self
Base64-encoded SHA512 checksum of the annotation payload.
Sourcepub fn set_checksum_sha512(self, input: Option<String>) -> Self
pub fn set_checksum_sha512(self, input: Option<String>) -> Self
Base64-encoded SHA512 checksum of the annotation payload.
Sourcepub fn get_checksum_sha512(&self) -> &Option<String>
pub fn get_checksum_sha512(&self) -> &Option<String>
Base64-encoded SHA512 checksum of the annotation payload.
Sourcepub fn checksum_md5(self, input: impl Into<String>) -> Self
pub fn checksum_md5(self, input: impl Into<String>) -> Self
Base64-encoded MD5 checksum of the annotation payload.
Sourcepub fn set_checksum_md5(self, input: Option<String>) -> Self
pub fn set_checksum_md5(self, input: Option<String>) -> Self
Base64-encoded MD5 checksum of the annotation payload.
Sourcepub fn get_checksum_md5(&self) -> &Option<String>
pub fn get_checksum_md5(&self) -> &Option<String>
Base64-encoded MD5 checksum of the annotation payload.
Sourcepub fn checksum_xxhash64(self, input: impl Into<String>) -> Self
pub fn checksum_xxhash64(self, input: impl Into<String>) -> Self
Base64-encoded XXHASH64 checksum of the annotation payload.
Sourcepub fn set_checksum_xxhash64(self, input: Option<String>) -> Self
pub fn set_checksum_xxhash64(self, input: Option<String>) -> Self
Base64-encoded XXHASH64 checksum of the annotation payload.
Sourcepub fn get_checksum_xxhash64(&self) -> &Option<String>
pub fn get_checksum_xxhash64(&self) -> &Option<String>
Base64-encoded XXHASH64 checksum of the annotation payload.
Sourcepub fn checksum_xxhash3(self, input: impl Into<String>) -> Self
pub fn checksum_xxhash3(self, input: impl Into<String>) -> Self
Base64-encoded XXHASH3 checksum of the annotation payload.
Sourcepub fn set_checksum_xxhash3(self, input: Option<String>) -> Self
pub fn set_checksum_xxhash3(self, input: Option<String>) -> Self
Base64-encoded XXHASH3 checksum of the annotation payload.
Sourcepub fn get_checksum_xxhash3(&self) -> &Option<String>
pub fn get_checksum_xxhash3(&self) -> &Option<String>
Base64-encoded XXHASH3 checksum of the annotation payload.
Sourcepub fn checksum_xxhash128(self, input: impl Into<String>) -> Self
pub fn checksum_xxhash128(self, input: impl Into<String>) -> Self
Base64-encoded XXHASH128 checksum of the annotation payload.
Sourcepub fn set_checksum_xxhash128(self, input: Option<String>) -> Self
pub fn set_checksum_xxhash128(self, input: Option<String>) -> Self
Base64-encoded XXHASH128 checksum of the annotation payload.
Sourcepub fn get_checksum_xxhash128(&self) -> &Option<String>
pub fn get_checksum_xxhash128(&self) -> &Option<String>
Base64-encoded XXHASH128 checksum of the annotation payload.
Sourcepub fn content_md5(self, input: impl Into<String>) -> Self
pub fn content_md5(self, input: impl Into<String>) -> Self
Base64-encoded MD5 digest of the message.
Sourcepub fn set_content_md5(self, input: Option<String>) -> Self
pub fn set_content_md5(self, input: Option<String>) -> Self
Base64-encoded MD5 digest of the message.
Sourcepub fn get_content_md5(&self) -> &Option<String>
pub fn get_content_md5(&self) -> &Option<String>
Base64-encoded MD5 digest of the message.
Sourcepub fn request_payer(self, input: RequestPayer) -> Self
pub fn request_payer(self, input: RequestPayer) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
pub fn set_request_payer(self, input: Option<RequestPayer>) -> Self
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_payer(&self) -> &Option<RequestPayer>
pub fn get_request_payer(&self) -> &Option<RequestPayer>
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
This functionality is not supported for directory buckets.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
Sourcepub fn build(self) -> Result<PutObjectAnnotationInput, BuildError>
pub fn build(self) -> Result<PutObjectAnnotationInput, BuildError>
Consumes the builder and constructs a PutObjectAnnotationInput.
Sourceimpl PutObjectAnnotationInputBuilder
impl PutObjectAnnotationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<PutObjectAnnotationOutput, SdkError<PutObjectAnnotationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<PutObjectAnnotationOutput, SdkError<PutObjectAnnotationError, HttpResponse>>
Sends a request with this input using the given client.