pub struct UpdateBucketMetadataAnnotationTableConfigurationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateBucketMetadataAnnotationTableConfiguration.
Updates the annotation table configuration for an Amazon S3 bucket's metadata configuration. Use this operation to enable or disable the annotation table, or to update its associated IAM role.
An annotation table is a queryable Iceberg table that contains records of all annotations attached to objects in the bucket. To use this operation, the bucket must have an existing Amazon S3 Metadata configuration.
To use this operation, you must have the s3:UpdateBucketMetadataAnnotationTableConfiguration permission. If you are specifying or changing the IAM role, you must also have iam:PassRole permission for the role.
The IAM role must have a trust policy that allows the Amazon S3 metadata service to assume it, and a permissions policy that grants the actions needed to read annotations from your bucket. The following examples show a trust policy and a permissions policy that you can adapt for your bucket and account.
The following operations are related to UpdateBucketMetadataAnnotationTableConfiguration:
Implementations
Sourceimpl UpdateBucketMetadataAnnotationTableConfigurationFluentBuilder
impl UpdateBucketMetadataAnnotationTableConfigurationFluentBuilder
Sourcepub fn as_input(
&self,
) -> &UpdateBucketMetadataAnnotationTableConfigurationInputBuilder
pub fn as_input( &self, ) -> &UpdateBucketMetadataAnnotationTableConfigurationInputBuilder
Access the UpdateBucketMetadataAnnotationTableConfiguration as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateBucketMetadataAnnotationTableConfigurationOutput, SdkError<UpdateBucketMetadataAnnotationTableConfigurationError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateBucketMetadataAnnotationTableConfigurationOutput, SdkError<UpdateBucketMetadataAnnotationTableConfigurationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateBucketMetadataAnnotationTableConfigurationOutput, UpdateBucketMetadataAnnotationTableConfigurationError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateBucketMetadataAnnotationTableConfigurationOutput, UpdateBucketMetadataAnnotationTableConfigurationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket whose annotation table configuration to update.
Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket whose annotation table configuration to update.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket whose annotation table configuration to update.
Sourcepub fn content_md5(self, input: impl Into<String>) -> Self
pub fn content_md5(self, input: impl Into<String>) -> Self
Base64-encoded MD5 digest of the message body.
Sourcepub fn set_content_md5(self, input: Option<String>) -> Self
pub fn set_content_md5(self, input: Option<String>) -> Self
Base64-encoded MD5 digest of the message body.
Sourcepub fn get_content_md5(&self) -> &Option<String>
pub fn get_content_md5(&self) -> &Option<String>
Base64-encoded MD5 digest of the message body.
Sourcepub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
pub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
Checksum algorithm for the request payload.
Sourcepub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
pub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
Checksum algorithm for the request payload.
Sourcepub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
pub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
Checksum algorithm for the request payload.
Sourcepub fn annotation_table_configuration(
self,
input: AnnotationTableConfigurationUpdates,
) -> Self
pub fn annotation_table_configuration( self, input: AnnotationTableConfigurationUpdates, ) -> Self
The annotation table configuration updates to apply.
Sourcepub fn set_annotation_table_configuration(
self,
input: Option<AnnotationTableConfigurationUpdates>,
) -> Self
pub fn set_annotation_table_configuration( self, input: Option<AnnotationTableConfigurationUpdates>, ) -> Self
The annotation table configuration updates to apply.
Sourcepub fn get_annotation_table_configuration(
&self,
) -> &Option<AnnotationTableConfigurationUpdates>
pub fn get_annotation_table_configuration( &self, ) -> &Option<AnnotationTableConfigurationUpdates>
The annotation table configuration updates to apply.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner.