#[non_exhaustive]pub struct AnnotationTableConfigurationResultBuilder { /* private fields */ }Expand description
A builder for AnnotationTableConfigurationResult.
Implementations
Sourceimpl AnnotationTableConfigurationResultBuilder
impl AnnotationTableConfigurationResultBuilder
Sourcepub fn configuration_state(self, input: AnnotationConfigurationState) -> Self
pub fn configuration_state(self, input: AnnotationConfigurationState) -> Self
The current configuration state of the annotation table.
This field is required.Sourcepub fn set_configuration_state(
self,
input: Option<AnnotationConfigurationState>,
) -> Self
pub fn set_configuration_state( self, input: Option<AnnotationConfigurationState>, ) -> Self
The current configuration state of the annotation table.
Sourcepub fn get_configuration_state(&self) -> &Option<AnnotationConfigurationState>
pub fn get_configuration_state(&self) -> &Option<AnnotationConfigurationState>
The current configuration state of the annotation table.
Sourcepub fn table_status(self, input: impl Into<String>) -> Self
pub fn table_status(self, input: impl Into<String>) -> Self
The provisioning status of the annotation table. Possible values: CREATING, BACKFILLING, ACTIVE, FAILED.
Sourcepub fn set_table_status(self, input: Option<String>) -> Self
pub fn set_table_status(self, input: Option<String>) -> Self
The provisioning status of the annotation table. Possible values: CREATING, BACKFILLING, ACTIVE, FAILED.
Sourcepub fn get_table_status(&self) -> &Option<String>
pub fn get_table_status(&self) -> &Option<String>
The provisioning status of the annotation table. Possible values: CREATING, BACKFILLING, ACTIVE, FAILED.
Sourcepub fn error(self, input: ErrorDetails) -> Self
pub fn error(self, input: ErrorDetails) -> Self
If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Sourcepub fn set_error(self, input: Option<ErrorDetails>) -> Self
pub fn set_error(self, input: Option<ErrorDetails>) -> Self
If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Sourcepub fn get_error(&self) -> &Option<ErrorDetails>
pub fn get_error(&self) -> &Option<ErrorDetails>
If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the annotation table.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the annotation table.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the annotation table.
Sourcepub fn set_table_arn(self, input: Option<String>) -> Self
pub fn set_table_arn(self, input: Option<String>) -> Self
The ARN of the annotation table.
Sourcepub fn get_table_arn(&self) -> &Option<String>
pub fn get_table_arn(&self) -> &Option<String>
The ARN of the annotation table.
Sourcepub fn role(self, input: impl Into<String>) -> Self
pub fn role(self, input: impl Into<String>) -> Self
The ARN of the IAM role associated with the annotation table.
Sourcepub fn set_role(self, input: Option<String>) -> Self
pub fn set_role(self, input: Option<String>) -> Self
The ARN of the IAM role associated with the annotation table.
Sourcepub fn get_role(&self) -> &Option<String>
pub fn get_role(&self) -> &Option<String>
The ARN of the IAM role associated with the annotation table.
Sourcepub fn build(self) -> Result<AnnotationTableConfigurationResult, BuildError>
pub fn build(self) -> Result<AnnotationTableConfigurationResult, BuildError>
Consumes the builder and constructs a AnnotationTableConfigurationResult.
This method will fail if any of the following fields are not set: