#[non_exhaustive]pub struct ObjectLockRuleBuilder { /* private fields */ }Expand description
A builder for ObjectLockRule.
Implementations
Sourceimpl ObjectLockRuleBuilder
impl ObjectLockRuleBuilder
Sourcepub fn default_retention(self, input: DefaultRetention) -> Self
pub fn default_retention(self, input: DefaultRetention) -> Self
The default Object Lock retention settings for new objects in this bucket. You can specify:
-
A default retention period, by using
DaysorYears. -
A default event hold duration, by using
DefaultEventHold. This setting also uses days or years.
You can set one or both. You cannot use days and years in the same setting.
Sourcepub fn set_default_retention(self, input: Option<DefaultRetention>) -> Self
pub fn set_default_retention(self, input: Option<DefaultRetention>) -> Self
The default Object Lock retention settings for new objects in this bucket. You can specify:
-
A default retention period, by using
DaysorYears. -
A default event hold duration, by using
DefaultEventHold. This setting also uses days or years.
You can set one or both. You cannot use days and years in the same setting.
Sourcepub fn get_default_retention(&self) -> &Option<DefaultRetention>
pub fn get_default_retention(&self) -> &Option<DefaultRetention>
The default Object Lock retention settings for new objects in this bucket. You can specify:
-
A default retention period, by using
DaysorYears. -
A default event hold duration, by using
DefaultEventHold. This setting also uses days or years.
You can set one or both. You cannot use days and years in the same setting.
Sourcepub fn build(self) -> ObjectLockRule
pub fn build(self) -> ObjectLockRule
Consumes the builder and constructs a ObjectLockRule.