#[non_exhaustive]pub struct AnnotationEntry {
pub annotation_name: String,
pub last_modified: DateTime,
pub e_tag: Option<String>,
pub checksum_algorithm: Option<Vec<ChecksumAlgorithm>>,
pub size: i64,
pub replication_status: Option<ReplicationStatus>,
}Expand description
Describes a single annotation attached to an object, including its name, last modified time, size, ETag, checksum algorithm, and replication status. Returned in the response from ListObjectAnnotations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.annotation_name: StringThe name of the annotation.
last_modified: DateTimeThe date and time the annotation was last modified.
e_tag: Option<String>The entity tag of the annotation.
checksum_algorithm: Option<Vec<ChecksumAlgorithm>>The checksum algorithm used for the annotation.
size: i64The size of the annotation payload, in bytes.
replication_status: Option<ReplicationStatus>The replication status of the annotation.
Implementations
Sourceimpl AnnotationEntry
impl AnnotationEntry
Sourcepub fn annotation_name(&self) -> &str
pub fn annotation_name(&self) -> &str
The name of the annotation.
Sourcepub fn last_modified(&self) -> &DateTime
pub fn last_modified(&self) -> &DateTime
The date and time the annotation was last modified.
Sourcepub fn checksum_algorithm(&self) -> &[ChecksumAlgorithm]
pub fn checksum_algorithm(&self) -> &[ChecksumAlgorithm]
The checksum algorithm used for the annotation.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .checksum_algorithm.is_none().
Sourcepub fn replication_status(&self) -> Option<&ReplicationStatus>
pub fn replication_status(&self) -> Option<&ReplicationStatus>
The replication status of the annotation.
Sourceimpl AnnotationEntry
impl AnnotationEntry
Sourcepub fn builder() -> AnnotationEntryBuilder
pub fn builder() -> AnnotationEntryBuilder
Creates a new builder-style object to manufacture AnnotationEntry.