#[non_exhaustive]pub struct AnnotationTableConfiguration {
pub configuration_state: AnnotationConfigurationState,
pub encryption_configuration: Option<MetadataTableEncryptionConfiguration>,
pub role: Option<String>,
}Expand description
Specifies the configuration for the annotation table associated with a bucket's Amazon S3 Metadata configuration. The annotation table is an Iceberg table that records annotation events for objects in the bucket.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.configuration_state: AnnotationConfigurationStateThe state of the annotation table. Valid values are ENABLED and DISABLED.
encryption_configuration: Option<MetadataTableEncryptionConfiguration>The encryption settings for an S3 Metadata journal table or inventory table configuration.
role: Option<String>The ARN of the IAM role used to manage the annotation table.
Implementations
Sourceimpl AnnotationTableConfiguration
impl AnnotationTableConfiguration
Sourcepub fn configuration_state(&self) -> &AnnotationConfigurationState
pub fn configuration_state(&self) -> &AnnotationConfigurationState
The state of the annotation table. Valid values are ENABLED and DISABLED.
Sourcepub fn encryption_configuration(
&self,
) -> Option<&MetadataTableEncryptionConfiguration>
pub fn encryption_configuration( &self, ) -> Option<&MetadataTableEncryptionConfiguration>
The encryption settings for an S3 Metadata journal table or inventory table configuration.
Sourceimpl AnnotationTableConfiguration
impl AnnotationTableConfiguration
Sourcepub fn builder() -> AnnotationTableConfigurationBuilder
pub fn builder() -> AnnotationTableConfigurationBuilder
Creates a new builder-style object to manufacture AnnotationTableConfiguration.