#[non_exhaustive]pub struct CopyPartResult {
pub e_tag: Option<String>,
pub last_modified: Option<DateTime>,
pub checksum_crc32: Option<String>,
pub checksum_crc32_c: Option<String>,
pub checksum_crc64_nvme: Option<String>,
pub checksum_sha1: Option<String>,
pub checksum_sha256: Option<String>,
pub checksum_sha512: Option<String>,
pub checksum_md5: Option<String>,
pub checksum_xxhash64: Option<String>,
pub checksum_xxhash3: Option<String>,
pub checksum_xxhash128: Option<String>,
}Expand description
Container for all response elements.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.e_tag: Option<String>Entity tag of the object.
last_modified: Option<DateTime>Date and time at which the object was uploaded.
checksum_crc32: Option<String>The Base64 encoded, 32-bit CRC32 checksum of the part. This checksum is present if the multipart upload request was created with the CRC32 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_crc32_c: Option<String>The Base64 encoded, 32-bit CRC32C checksum of the part. This checksum is present if the multipart upload request was created with the CRC32C checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_crc64_nvme: Option<String>The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_sha1: Option<String>The Base64 encoded, 160-bit SHA1 digest of the part. This checksum is present if the multipart upload request was created with the SHA1 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_sha256: Option<String>The Base64 encoded, 256-bit SHA256 digest of the part. This checksum is present if the multipart upload request was created with the SHA256 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_sha512: Option<String>The Base64 encoded, 512-bit SHA512 digest of the part. This checksum is present if the multipart upload request was created with the SHA512 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_md5: Option<String>The Base64 encoded, 128-bit MD5 digest of the part. This checksum is present if the multipart upload request was created with the MD5 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_xxhash64: Option<String>The Base64 encoded, 64-bit XXHASH64 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH64 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_xxhash3: Option<String>The Base64 encoded, 64-bit XXHASH3 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH3 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_xxhash128: Option<String>The Base64 encoded, 128-bit XXHASH128 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH128 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Implementations
Sourceimpl CopyPartResult
impl CopyPartResult
Sourcepub fn last_modified(&self) -> Option<&DateTime>
pub fn last_modified(&self) -> Option<&DateTime>
Date and time at which the object was uploaded.
Sourcepub fn checksum_crc32(&self) -> Option<&str>
pub fn checksum_crc32(&self) -> Option<&str>
The Base64 encoded, 32-bit CRC32 checksum of the part. This checksum is present if the multipart upload request was created with the CRC32 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc32_c(&self) -> Option<&str>
pub fn checksum_crc32_c(&self) -> Option<&str>
The Base64 encoded, 32-bit CRC32C checksum of the part. This checksum is present if the multipart upload request was created with the CRC32C checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc64_nvme(&self) -> Option<&str>
pub fn checksum_crc64_nvme(&self) -> Option<&str>
The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha1(&self) -> Option<&str>
pub fn checksum_sha1(&self) -> Option<&str>
The Base64 encoded, 160-bit SHA1 digest of the part. This checksum is present if the multipart upload request was created with the SHA1 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha256(&self) -> Option<&str>
pub fn checksum_sha256(&self) -> Option<&str>
The Base64 encoded, 256-bit SHA256 digest of the part. This checksum is present if the multipart upload request was created with the SHA256 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha512(&self) -> Option<&str>
pub fn checksum_sha512(&self) -> Option<&str>
The Base64 encoded, 512-bit SHA512 digest of the part. This checksum is present if the multipart upload request was created with the SHA512 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_md5(&self) -> Option<&str>
pub fn checksum_md5(&self) -> Option<&str>
The Base64 encoded, 128-bit MD5 digest of the part. This checksum is present if the multipart upload request was created with the MD5 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_xxhash64(&self) -> Option<&str>
pub fn checksum_xxhash64(&self) -> Option<&str>
The Base64 encoded, 64-bit XXHASH64 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH64 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_xxhash3(&self) -> Option<&str>
pub fn checksum_xxhash3(&self) -> Option<&str>
The Base64 encoded, 64-bit XXHASH3 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH3 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_xxhash128(&self) -> Option<&str>
pub fn checksum_xxhash128(&self) -> Option<&str>
The Base64 encoded, 128-bit XXHASH128 checksum of the part. This checksum is present if the multipart upload request was created with the XXHASH128 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourceimpl CopyPartResult
impl CopyPartResult
Sourcepub fn builder() -> CopyPartResultBuilder
pub fn builder() -> CopyPartResultBuilder
Creates a new builder-style object to manufacture CopyPartResult.